@@ -5,8 +5,8 @@
  * contributions from numerous individuals and organizations.
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
-#ifndef SQUID_OS_ANDROID_H
-#define SQUID_OS_ANDROID_H
+#ifndef SQUID_COMPAT_OS_ANDROID_H
+#define SQUID_COMPAT_OS_ANDROID_H
 
 #if defined(__ANDROID__)
 /****************************************************************************
@@ -17,5 +17,5 @@
 #define _SQUID_ANDROID_ 1
 
 #endif /* _SQUID_ANDROID_ */
-#endif /* SQUID_OS_ANDROID_H */
+#endif /* SQUID_COMPAT_OS_ANDROID_H */
 
