@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_OS_HPUX_H
-#define SQUID_OS_HPUX_H
+#ifndef SQUID_COMPAT_OS_HPUX_H
+#define SQUID_COMPAT_OS_HPUX_H
 
 #if _SQUID_HPUX_
 
@@ -39,5 +39,5 @@
 #endif
 
 #endif /* _SQUID_HPUX_ */
-#endif /* SQUID_OS_HPUX_H */
+#endif /* SQUID_COMPAT_OS_HPUX_H */
 
