@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_OS_OPENBSD_H
-#define SQUID_OS_OPENBSD_H
+#ifndef SQUID_COMPAT_OS_OPENBSD_H
+#define SQUID_COMPAT_OS_OPENBSD_H
 
 #if _SQUID_OPENBSD_
 
@@ -47,5 +47,5 @@
 #endif
 
 #endif /* _SQUID_OPENBSD_ */
-#endif /* SQUID_OS_OPENBSD_H */
+#endif /* SQUID_COMPAT_OS_OPENBSD_H */
 
