@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_OS_OS2_H
-#define SQUID_OS_OS2_H
+#ifndef SQUID_COMPAT_OS_OS2_H
+#define SQUID_COMPAT_OS_OS2_H
 
 #if _SQUID_OS2_
 
@@ -24,5 +24,5 @@
 */
 
 #endif /* _SQUID_OS2_ */
-#endif /* SQUID_OS_OS2_H */
+#endif /* SQUID_COMPAT_OS_OS2_H */
 
