@@ -50,5 +50,5 @@ extern "C" {
 /// Determines whether segment names are iterpreted as full file paths.
 bool shm_portable_segment_name_is_path();
 
-#endif /* SQUID_COMPAT_CPU_H */
+#endif /* SQUID_COMPAT_SHM_H */
 
