@@ -1,13 +1,13 @@
 /*
- * Copyright (C) 1996-2022 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2023 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef _SQUID_STDVARARGS_H
-#define _SQUID_STDVARARGS_H
+#ifndef SQUID_COMPAT_STDVARARGS_H
+#define SQUID_COMPAT_STDVARARGS_H
 
 /*
  * va_* variables come from various places on different platforms.
@@ -46,5 +46,5 @@
 #include <syslog.h>
 #endif
 
-#endif /* _SQUID_STDVARARGS_H */
+#endif /* SQUID_COMPAT_STDVARARGS_H */
 
