@@ -1,13 +1,13 @@
 /*
- * Copyright (C) 1996-2022 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2023 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef _SQUID_COMPAT_XIS_H
-#define _SQUID_COMPAT_XIS_H
+#ifndef SQUID_COMPAT_XIS_H
+#define SQUID_COMPAT_XIS_H
 
 #if HAVE_CTYPE_H
 #include <ctype.h>
@@ -46,5 +46,5 @@
 #define xisgraph(x) isgraph((unsigned char)x)
 #endif
 
-#endif /* _SQUID_COMPAT_XIS_H */
+#endif /* SQUID_COMPAT_XIS_H */
 
