@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_RADIX_H
-#define SQUID_RADIX_H
+#ifndef SQUID_INCLUDE_RADIX_H
+#define SQUID_INCLUDE_RADIX_H
 
 /*
  * Copyright (c) 1988, 1989, 1993
@@ -159,5 +159,5 @@ SQUIDCEXTERN struct squid_radix_node *squid_rn_search_m(void *, struct squid_rad
 
 SQUIDCEXTERN struct squid_radix_node *squid_rn_lookup(void *, void *, struct squid_radix_node_head *);
 
-#endif /* SQUID_RADIX_H */
+#endif /* SQUID_INCLUDE_RADIX_H */
 
