@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_SNMP_H
-#define SQUID_SNMP_H
+#ifndef SQUID_INCLUDE_SNMP_H
+#define SQUID_INCLUDE_SNMP_H
 
 /*
  * Definitions for the Simple Network Management Protocol (RFC 1067).
@@ -67,5 +67,5 @@
 #include "snmp_debug.h"
 #include "snmp_impl.h"
 
-#endif /* SQUID_SNMP_H */
+#endif /* SQUID_INCLUDE_SNMP_H */
 
