@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_SNMP_API_H
-#define SQUID_SNMP_API_H
+#ifndef SQUID_INCLUDE_SNMP_API_H
+#define SQUID_INCLUDE_SNMP_API_H
 
 /***********************************************************
     Copyright 1989 by Carnegie Mellon University
@@ -68,5 +68,5 @@ int snmp_build(struct snmp_session *, struct snmp_pdu *, u_char *, int *);
 
 #endif
 
-#endif              /* SQUID_SNMP_API_H */
+#endif /* SQUID_INCLUDE_SNMP_API_H */
 
