@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_SNMP_CLIENT_H
-#define SQUID_SNMP_CLIENT_H
+#ifndef SQUID_INCLUDE_SNMP_CLIENT_H
+#define SQUID_INCLUDE_SNMP_CLIENT_H
 
 /***********************************************************
     Copyright 1988, 1989 by Carnegie Mellon University
@@ -62,5 +62,5 @@ void snmp_synch_setup(struct snmp_session *);
 }
 #endif
 
-#endif              /* SQUID_SNMP_CLIENT_H */
+#endif /* SQUID_INCLUDE_SNMP_CLIENT_H */
 
