@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_SNMP_ERROR_H
-#define SQUID_SNMP_ERROR_H
+#ifndef SQUID_INCLUDE_SNMP_ERROR_H
+#define SQUID_INCLUDE_SNMP_ERROR_H
 
 /**********************************************************************
  *
@@ -71,5 +71,5 @@ const char *snmp_errstring(int);
 }
 #endif
 
-#endif              /* SQUID_SNMP_ERROR_H */
+#endif /* SQUID_INCLUDE_SNMP_ERROR_H */
 
