@@ -30,8 +30,8 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ifndef _RFCNB_RFCNB_PRIV_H
-#define _RFCNB_RFCNB_PRIV_H
+#ifndef SQUID_LIB_RFCNB_RFCNB_PRIV_H
+#define SQUID_LIB_RFCNB_RFCNB_PRIV_H
 
 /* Defines we need */
 
@@ -130,5 +130,5 @@ extern int RFCNB_errno;
 extern int RFCNB_saved_errno;   /* Save this from point of error */
 #endif
 
-#endif /* _RFCNB_RFCNB_PRIV_H */
+#endif /* SQUID_LIB_RFCNB_RFCNB_PRIV_H */
 
