@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef _SMBLIB_SMBENCRYPT_H
-#define _SMBLIB_SMBENCRYPT_H
+#ifndef SQUID_LIB_SMBLIB_SMBENCRYPT_H
+#define SQUID_LIB_SMBLIB_SMBENCRYPT_H
 
 #ifdef __cplusplus
 extern "C" {
@@ -20,5 +20,5 @@ void nt_lm_owf_gen(char *pwd, char *nt_p16, char *p16);
 #ifdef __cplusplus
 }
 #endif
-#endif /* _SMBLIB_SMBENCRYPT_H */
+#endif /* SQUID_LIB_SMBLIB_SMBENCRYPT_H */
 
