@@ -30,8 +30,8 @@
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
 
-#ifndef _SMBLIB_PRIV_H_
-#define _SMBLIB_PRIV_H_
+#ifndef SQUID_LIB_SMBLIB_SMBLIB_PRIV_H
+#define SQUID_LIB_SMBLIB_SMBLIB_PRIV_H
 
 #include "smblib/smblib-common.h"
 #include "smblib/std-defines.h"
@@ -551,5 +551,5 @@ extern int SMBlib_SMB_Error;          /* last Error             */
 
 void SMB_Get_My_Name(char *name, int len);
 
-#endif /* _SMBLIB_PRIV_H_ */
+#endif /* SQUID_LIB_SMBLIB_SMBLIB_PRIV_H */
 
