@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_CLIENTREQUESTCONTEXT_H
-#define SQUID_CLIENTREQUESTCONTEXT_H
+#ifndef SQUID_SRC_CLIENTREQUESTCONTEXT_H
+#define SQUID_SRC_CLIENTREQUESTCONTEXT_H
 
 #include "base/RefCount.h"
 #include "cbdata.h"
@@ -87,5 +87,5 @@ public:
 #endif
 };
 
-#endif /* SQUID_CLIENTREQUESTCONTEXT_H */
+#endif /* SQUID_SRC_CLIENTREQUESTCONTEXT_H */
 
