@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_CPU_AFFINITY_MAP_H
-#define SQUID_CPU_AFFINITY_MAP_H
+#ifndef SQUID_SRC_CPUAFFINITYMAP_H
+#define SQUID_SRC_CPUAFFINITYMAP_H
 
 #include <vector>
 
@@ -34,5 +34,5 @@ private:
     std::vector<int> theCores; ///< list of cores
 };
 
-#endif // SQUID_CPU_AFFINITY_MAP_H
+#endif /* SQUID_SRC_CPUAFFINITYMAP_H */
 
