@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2022 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2023 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
@@ -8,8 +8,8 @@
 
 /* DEBUG: section 03    Configuration Settings */
 
-#ifndef SQUID_DELAYCONFIG_H
-#define SQUID_DELAYCONFIG_H
+#ifndef SQUID_SRC_DELAYCONFIG_H
+#define SQUID_SRC_DELAYCONFIG_H
 
 class StoreEntry;
 class ConfigParser;
@@ -29,5 +29,5 @@ public:
 
 };
 
-#endif /* SQUID_DELAYCONFIG_H */
+#endif /* SQUID_SRC_DELAYCONFIG_H */
 
