@@ -8,12 +8,13 @@
 
 /* DEBUG: section 77    Delay Pools */
 
-#ifndef DELAYTAGGED_H
-#define DELAYTAGGED_H
+#ifndef SQUID_SRC_DELAYTAGGED_H
+#define SQUID_SRC_DELAYTAGGED_H
 
 #if USE_DELAY_POOLS
 
 #include "auth/Gadgets.h"
+#include "base/forward.h"
 #include "CompositePoolNode.h"
 #include "DelayBucket.h"
 #include "DelayIdComposite.h"
@@ -30,7 +31,7 @@ public:
 
     void stats(StoreEntry *)const;
     DelayTaggedBucket(String &aTag);
-    ~DelayTaggedBucket();
+    ~DelayTaggedBucket() override;
     DelayBucket theBucket;
     String tag;
 };
@@ -44,13 +45,13 @@ public:
     typedef RefCount<DelayTagged> Pointer;
 
     DelayTagged();
-    virtual ~DelayTagged();
-    virtual void stats(StoreEntry * sentry);
-    virtual void dump(StoreEntry *entry) const;
-    virtual void update(int incr);
-    virtual void parse();
+    ~DelayTagged() override;
+    void stats(StoreEntry * sentry) override;
+    void dump(StoreEntry *entry) const override;
+    void update(int incr) override;
+    void parse() override;
 
-    virtual DelayIdComposite::Pointer id(CompositeSelectionDetails &);
+    DelayIdComposite::Pointer id(CompositeSelectionDetails &) override;
 
 private:
 
@@ -61,10 +62,10 @@ private:
 
     public:
         Id (RefCount<DelayTagged>, String &);
-        ~Id();
-        virtual int bytesWanted (int min, int max) const;
-        virtual void bytesIn(int qty);
-        virtual void delayRead(DeferredRead const &);
+        ~Id() override;
+        int bytesWanted (int min, int max) const override;
+        void bytesIn(int qty) override;
+        void delayRead(const AsyncCallPointer &) override;
 
     private:
         RefCount<DelayTagged> theTagged;
@@ -78,5 +79,5 @@ private:
 };
 
 #endif /* USE_DELAY_POOLS */
-#endif /* DELAYTAGGED_H */
+#endif /* SQUID_SRC_DELAYTAGGED_H */
 
