@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_AIODISKIOMODULE_H
-#define SQUID_AIODISKIOMODULE_H
+#ifndef SQUID_SRC_DISKIO_AIO_AIODISKIOMODULE_H
+#define SQUID_SRC_DISKIO_AIO_AIODISKIOMODULE_H
 
 #if HAVE_DISKIO_MODULE_AIO
 
@@ -19,15 +19,15 @@ class AIODiskIOModule : public DiskIOModule
 public:
     static AIODiskIOModule &GetInstance();
     AIODiskIOModule();
-    virtual void init();
-    virtual void gracefulShutdown();
-    virtual char const *type () const;
-    virtual DiskIOStrategy* createStrategy();
+    void init() override;
+    void gracefulShutdown() override;
+    char const *type () const override;
+    DiskIOStrategy* createStrategy() override;
 
 private:
     static AIODiskIOModule Instance;
 };
 
 #endif /* HAVE_DISKIO_MODULE_AIO */
-#endif /* SQUID_AIODISKIOMODULE_H */
+#endif /* SQUID_SRC_DISKIO_AIO_AIODISKIOMODULE_H */
 
