@@ -1,13 +1,13 @@
 /*
- * Copyright (C) 1996-2022 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2023 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_DISKDAEMONDISKIOMODULE_H
-#define SQUID_DISKDAEMONDISKIOMODULE_H
+#ifndef SQUID_SRC_DISKIO_DISKDAEMON_DISKDAEMONDISKIOMODULE_H
+#define SQUID_SRC_DISKIO_DISKDAEMON_DISKDAEMONDISKIOMODULE_H
 
 #include "DiskIO/DiskIOModule.h"
 
@@ -17,10 +17,10 @@ class DiskDaemonDiskIOModule : public DiskIOModule
 public:
     static DiskDaemonDiskIOModule &GetInstance();
     DiskDaemonDiskIOModule();
-    virtual void init();
-    virtual void gracefulShutdown();
-    virtual char const *type () const;
-    virtual DiskIOStrategy* createStrategy();
+    void init() override;
+    void gracefulShutdown() override;
+    char const *type () const override;
+    DiskIOStrategy* createStrategy() override;
 
 private:
     static DiskDaemonDiskIOModule Instance;
@@ -28,5 +28,5 @@ private:
     void registerWithCacheManager(void);
 };
 
-#endif /* SQUID_DISKDAEMONDISKIOMODULE_H */
+#endif /* SQUID_SRC_DISKIO_DISKDAEMON_DISKDAEMONDISKIOMODULE_H */
 
