@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_DISKFILE_H
-#define SQUID_DISKFILE_H
+#ifndef SQUID_SRC_DISKIO_DISKFILE_H
+#define SQUID_SRC_DISKIO_DISKFILE_H
 
 #include "base/RefCount.h"
 #include "time/gadgets.h"
@@ -58,5 +58,5 @@ public:
     virtual bool ioInProgress() const = 0;
 };
 
-#endif /* SQUID_DISKFILE_H */
+#endif /* SQUID_SRC_DISKIO_DISKFILE_H */
 
