@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_DISKIOMODULE_H
-#define SQUID_DISKIOMODULE_H
+#ifndef SQUID_SRC_DISKIO_DISKIOMODULE_H
+#define SQUID_SRC_DISKIO_DISKIOMODULE_H
 
 #include <vector>
 
@@ -57,5 +57,5 @@ private:
     static std::vector<DiskIOModule*> *_Modules;
 };
 
-#endif /* SQUID_DISKIOMODULE_H */
+#endif /* SQUID_SRC_DISKIO_DISKIOMODULE_H */
 
