@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_DISKTHREADSDISKIOMODULE_H
-#define SQUID_DISKTHREADSDISKIOMODULE_H
+#ifndef SQUID_SRC_DISKIO_DISKTHREADS_DISKTHREADSDISKIOMODULE_H
+#define SQUID_SRC_DISKIO_DISKTHREADS_DISKTHREADSDISKIOMODULE_H
 
 #include "DiskIO/DiskIOModule.h"
 
@@ -17,15 +17,15 @@ class DiskThreadsDiskIOModule : public DiskIOModule
 public:
     static DiskThreadsDiskIOModule &GetInstance();
     DiskThreadsDiskIOModule();
-    virtual void init();
+    void init() override;
     //virtual void registerWithCacheManager(void);
-    virtual void gracefulShutdown();
-    virtual char const *type () const;
-    virtual DiskIOStrategy* createStrategy();
+    void gracefulShutdown() override;
+    char const *type () const override;
+    DiskIOStrategy* createStrategy() override;
 
 private:
     static DiskThreadsDiskIOModule Instance;
 };
 
-#endif /* SQUID_DISKTHREADSDISKIOMODULE_H */
+#endif /* SQUID_SRC_DISKIO_DISKTHREADS_DISKTHREADSDISKIOMODULE_H */
 
