@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_IOREQUESTOR_H
-#define SQUID_IOREQUESTOR_H
+#ifndef SQUID_SRC_DISKIO_IOREQUESTOR_H
+#define SQUID_SRC_DISKIO_IOREQUESTOR_H
 
 #include "base/RefCount.h"
 
@@ -26,5 +26,5 @@ public:
     virtual void writeCompleted(int errflag, size_t len, RefCount<WriteRequest>) = 0;
 };
 
-#endif /* SQUID_IOREQUESTOR_H */
+#endif /* SQUID_SRC_DISKIO_IOREQUESTOR_H */
 
