@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_IPC_IODISKIOMODULE_H
-#define SQUID_IPC_IODISKIOMODULE_H
+#ifndef SQUID_SRC_DISKIO_IPCIO_IPCIODISKIOMODULE_H
+#define SQUID_SRC_DISKIO_IPCIO_IPCIODISKIOMODULE_H
 
 #include "DiskIO/DiskIOModule.h"
 
@@ -17,14 +17,14 @@ class IpcIoDiskIOModule : public DiskIOModule
 public:
     static IpcIoDiskIOModule &GetInstance();
     IpcIoDiskIOModule();
-    virtual void init();
-    virtual void gracefulShutdown();
-    virtual char const *type () const;
-    virtual DiskIOStrategy* createStrategy();
+    void init() override;
+    void gracefulShutdown() override;
+    char const *type () const override;
+    DiskIOStrategy* createStrategy() override;
 
 private:
     static IpcIoDiskIOModule Instance;
 };
 
-#endif /* SQUID_IPC_IODISKIOMODULE_H */
+#endif /* SQUID_SRC_DISKIO_IPCIO_IPCIODISKIOMODULE_H */
 
