@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_IPC_IOFILE_H
-#define SQUID_IPC_IOFILE_H
+#ifndef SQUID_SRC_DISKIO_IPCIO_IPCIOFILE_H
+#define SQUID_SRC_DISKIO_IPCIO_IPCIOFILE_H
 
 #include "base/AsyncCall.h"
 #include "cbdata.h"
@@ -185,5 +185,5 @@ private:
     IpcIoPendingRequest &operator =(const IpcIoPendingRequest &d); // ditto
 };
 
-#endif /* SQUID_IPC_IOFILE_H */
+#endif /* SQUID_SRC_DISKIO_IPCIO_IPCIOFILE_H */
 
