@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_MMAPPEDDISKIOMODULE_H
-#define SQUID_MMAPPEDDISKIOMODULE_H
+#ifndef SQUID_SRC_DISKIO_MMAPPED_MMAPPEDDISKIOMODULE_H
+#define SQUID_SRC_DISKIO_MMAPPED_MMAPPEDDISKIOMODULE_H
 
 #include "DiskIO/DiskIOModule.h"
 
@@ -17,14 +17,14 @@ class MmappedDiskIOModule : public DiskIOModule
 public:
     static MmappedDiskIOModule &GetInstance();
     MmappedDiskIOModule();
-    virtual void init();
-    virtual void gracefulShutdown();
-    virtual char const *type () const;
-    virtual DiskIOStrategy* createStrategy();
+    void init() override;
+    void gracefulShutdown() override;
+    char const *type () const override;
+    DiskIOStrategy* createStrategy() override;
 
 private:
     static MmappedDiskIOModule Instance;
 };
 
-#endif /* SQUID_MMAPPEDDISKIOMODULE_H */
+#endif /* SQUID_SRC_DISKIO_MMAPPED_MMAPPEDDISKIOMODULE_H */
 
