@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_HAPPYCONNOPENER_H
-#define SQUID_HAPPYCONNOPENER_H
+#ifndef SQUID_SRC_HAPPYCONNOPENER_H
+#define SQUID_SRC_HAPPYCONNOPENER_H
 #include "base/RefCount.h"
 #include "comm.h"
 #include "comm/Connection.h"
@@ -245,5 +245,5 @@ private:
     mutable const char *ranOutOfTimeOrAttemptsEarlier_ = nullptr;
 };
 
-#endif
+#endif /* SQUID_SRC_HAPPYCONNOPENER_H */
 
