@@ -6,13 +6,13 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_HTTPHEADERMASK_H
-#define SQUID_HTTPHEADERMASK_H
+#ifndef SQUID_SRC_HTTPHEADERMASK_H
+#define SQUID_SRC_HTTPHEADERMASK_H
 
 /* big mask for http headers */
 typedef char HttpHeaderMask[12];
 
 void httpHeaderMaskInit(HttpHeaderMask * mask, int value);
 
-#endif /* SQUID_HTTPHEADERMASK_H */
+#endif /* SQUID_SRC_HTTPHEADERMASK_H */
 
