@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_HTTPHEADERRANGE_H
-#define SQUID_HTTPHEADERRANGE_H
+#ifndef SQUID_SRC_HTTPHEADERRANGE_H
+#define SQUID_SRC_HTTPHEADERRANGE_H
 
 #include "base/Range.h"
 #include "mem/forward.h"
@@ -107,5 +107,5 @@ public:
     bool valid = false;
 };
 
-#endif /* SQUID_HTTPHEADERRANGE_H */
+#endif /* SQUID_SRC_HTTPHEADERRANGE_H */
 
