@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_INSTANCE_H
-#define SQUID_INSTANCE_H
+#ifndef SQUID_SRC_INSTANCE_H
+#define SQUID_SRC_INSTANCE_H
 
 #if HAVE_SYS_TYPES_H
 #include <sys/types.h>
@@ -32,5 +32,5 @@ pid_t Other();
 
 } // namespace Instance
 
-#endif
+#endif /* SQUID_SRC_INSTANCE_H */
 
