@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_LOADABLE_MODULES_H
-#define SQUID_LOADABLE_MODULES_H
+#ifndef SQUID_SRC_LOADABLEMODULES_H
+#define SQUID_SRC_LOADABLEMODULES_H
 
 // TODO: add reporting for cachemgr
 // TODO: add reconfiguration support
@@ -15,5 +15,5 @@
 class wordlist;
 void LoadableModulesConfigure(const wordlist *names);
 
-#endif /* SQUID_LOADABLE_MODULES_H */
+#endif /* SQUID_SRC_LOADABLEMODULES_H */
 
