@@ -8,8 +8,8 @@
 
 /* DEBUG: section 54    Interprocess Communication */
 
-#ifndef SQUID_SQUIDIPC_H_
-#define SQUID_SQUIDIPC_H_
+#ifndef SQUID_SRC_SQUIDIPC_H
+#define SQUID_SRC_SQUIDIPC_H
 
 namespace Ip
 {
@@ -24,5 +24,5 @@ pid_t ipcCreate(int type,
                 int *wfd,
                 void **hIpc);
 
-#endif /* SQUID_SQUIDIPC_H_ */
+#endif /* SQUID_SRC_SQUIDIPC_H */
 
