@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef _SQUID_TIMEORTAG_H
-#define _SQUID_TIMEORTAG_H
+#ifndef SQUID_SRC_TIMEORTAG_H
+#define SQUID_SRC_TIMEORTAG_H
 
 #include "ETag.h"
 
@@ -22,5 +22,5 @@ public:
     int valid;                  /* true if struct is usable */
 };
 
-#endif /* _SQUID_TIMEORTAG_H */
+#endif /* SQUID_SRC_TIMEORTAG_H */
 
