@@ -8,7 +8,7 @@
 
 #include "squid.h"
 #include "cache_cf.h"
-#include "Debug.h"
+#include "debug/Stream.h"
 #include "XactionInitiator.h"
 
 #include <map>
