@@ -1,13 +1,13 @@
 /*
- * Copyright (C) 1996-2022 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2023 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_ACLDENYINFOLIST_H_
-#define SQUID_ACLDENYINFOLIST_H_
+#ifndef SQUID_SRC_ACL_ACLDENYINFOLIST_H
+#define SQUID_SRC_ACL_ACLDENYINFOLIST_H
 
 #include "acl/forward.h"
 #include "error/forward.h"
@@ -40,5 +40,5 @@ public:
     AclDenyInfoList *next = nullptr;
 };
 
-#endif /* SQUID_ACLDENYINFOLIST_H_ */
+#endif /* SQUID_SRC_ACL_ACLDENYINFOLIST_H */
 
