@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_ADAPTATIONSERVICEDATA_H
-#define SQUID_ADAPTATIONSERVICEDATA_H
+#ifndef SQUID_SRC_ACL_ADAPTATIONSERVICEDATA_H
+#define SQUID_SRC_ACL_ADAPTATIONSERVICEDATA_H
 
 #include "acl/Acl.h"
 #include "acl/Data.h"
@@ -21,5 +21,5 @@ public:
     void parse() override;
 };
 
-#endif /* SQUID_ADAPTATIONSERVICEDATA_H */
+#endif /* SQUID_SRC_ACL_ADAPTATIONSERVICEDATA_H */
 
