@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_ACL_ALL_OF_H
-#define SQUID_ACL_ALL_OF_H
+#ifndef SQUID_SRC_ACL_ALLOF_H
+#define SQUID_SRC_ACL_ALLOF_H
 
 #include "acl/InnerNode.h"
 
@@ -34,5 +34,5 @@ private:
 
 } // namespace Acl
 
-#endif /* SQUID_ACL_ALL_OF_H */
+#endif /* SQUID_SRC_ACL_ALLOF_H */
 
