@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_ACLARP_H
-#define SQUID_ACLARP_H
+#ifndef SQUID_SRC_ACL_ARP_H
+#define SQUID_SRC_ACL_ARP_H
 
 #include "acl/Acl.h"
 
@@ -39,5 +39,5 @@ protected:
     AclArpData_t aclArpData;
 };
 
-#endif /* SQUID_ACLARP_H */
+#endif /* SQUID_SRC_ACL_ARP_H */
 
