@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_ACLATSTEP_H
-#define SQUID_ACLATSTEP_H
+#ifndef SQUID_SRC_ACL_ATSTEP_H
+#define SQUID_SRC_ACL_ATSTEP_H
 
 #include "acl/Strategy.h"
 #include "XactionStep.h"
@@ -17,8 +17,8 @@ class ACLAtStepStrategy: public ACLStrategy<XactionStep>
 {
 
 public:
-    virtual int match (ACLData<MatchType> * &, ACLFilledChecklist *) override;
+    int match (ACLData<MatchType> * &, ACLFilledChecklist *) override;
 };
 
-#endif /* SQUID_ACLATSTEP_H */
+#endif /* SQUID_SRC_ACL_ATSTEP_H */
 
