@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_ACLCERTIFICATEDATA_H
-#define SQUID_ACLCERTIFICATEDATA_H
+#ifndef SQUID_SRC_ACL_CERTIFICATEDATA_H
+#define SQUID_SRC_ACL_CERTIFICATEDATA_H
 
 #include "acl/Acl.h"
 #include "acl/Data.h"
@@ -45,5 +45,5 @@ private:
     Ssl::GETX509ATTRIBUTE *sslAttributeCall;
 };
 
-#endif /* SQUID_ACLCERTIFICATEDATA_H */
+#endif /* SQUID_SRC_ACL_CERTIFICATEDATA_H */
 
