@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_ACLCHECKLIST_H
-#define SQUID_ACLCHECKLIST_H
+#ifndef SQUID_SRC_ACL_CHECKLIST_H
+#define SQUID_SRC_ACL_CHECKLIST_H
 
 #include "acl/InnerNode.h"
 #include <stack>
@@ -245,5 +245,5 @@ private: /* internal methods */
     std::vector<Acl::Answer> bannedActions_;
 };
 
-#endif /* SQUID_ACLCHECKLIST_H */
+#endif /* SQUID_SRC_ACL_CHECKLIST_H */
 
