@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_ACLDESTINATIONASN_H
-#define SQUID_ACLDESTINATIONASN_H
+#ifndef SQUID_SRC_ACL_DESTINATIONASN_H
+#define SQUID_SRC_ACL_DESTINATIONASN_H
 
 #include "acl/Asn.h"
 #include "acl/Strategy.h"
@@ -22,5 +22,5 @@ public:
     bool requiresRequest() const override {return true;}
 };
 
-#endif /* SQUID_ACLDESTINATIONASN_H */
+#endif /* SQUID_SRC_ACL_DESTINATIONASN_H */
 
