@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_ACLDESTINATIONDOMAIN_H
-#define SQUID_ACLDESTINATIONDOMAIN_H
+#ifndef SQUID_SRC_ACL_DESTINATIONDOMAIN_H
+#define SQUID_SRC_ACL_DESTINATIONDOMAIN_H
 
 #include "acl/Acl.h"
 #include "acl/Checklist.h"
@@ -21,9 +21,9 @@ class ACLDestinationDomainStrategy : public ACLStrategy<char const *>
 
 public:
     /* ACLStrategy API */
-    virtual int match (ACLData<MatchType> * &, ACLFilledChecklist *);
-    virtual bool requiresRequest() const {return true;}
-    virtual const Acl::Options &options();
+    int match (ACLData<MatchType> * &, ACLFilledChecklist *) override;
+    bool requiresRequest() const override {return true;}
+    const Acl::Options &options() override;
 
 private:
     Acl::BooleanOptionValue lookupBanned; ///< Are DNS lookups allowed?
@@ -35,12 +35,12 @@ class DestinationDomainLookup : public ACLChecklist::AsyncState
 
 public:
     static DestinationDomainLookup *Instance();
-    virtual void checkForAsync(ACLChecklist *)const;
+    void checkForAsync(ACLChecklist *)const override;
 
 private:
     static DestinationDomainLookup instance_;
     static void LookupDone(const char *, const Dns::LookupDetails &, void *);
 };
 
-#endif /* SQUID_ACLDESTINATIONDOMAIN_H */
+#endif /* SQUID_SRC_ACL_DESTINATIONDOMAIN_H */
 
