@@ -26,8 +26,8 @@ ACLDestinationIP::typeString() const
 const Acl::Options &
 ACLDestinationIP::options()
 {
-    static const Acl::BooleanOption LookupBan;
-    static const Acl::Options MyOptions = { { "-n", &LookupBan } };
+    static const Acl::BooleanOption LookupBan("-n");
+    static const Acl::Options MyOptions = { &LookupBan };
     LookupBan.linkWith(&lookupBanned);
     return MyOptions;
 }
@@ -108,9 +108,3 @@ DestinationIPLookup::LookupDone(const ipcache_addrs *, const Dns::LookupDetails
     checklist->resumeNonBlockingCheck(DestinationIPLookup::Instance());
 }
 
-ACL *
-ACLDestinationIP::clone() const
-{
-    return new ACLDestinationIP(*this);
-}
-
