@@ -11,6 +11,7 @@
 #include "client_side.h"
 #include "comm/Connection.h"
 #include "comm/forward.h"
+#include "debug/Messages.h"
 #include "ExternalACLEntry.h"
 #include "http/Stream.h"
 #include "HttpReply.h"
@@ -24,20 +25,17 @@
 CBDATA_CLASS_INIT(ACLFilledChecklist);
 
 ACLFilledChecklist::ACLFilledChecklist() :
-    dst_rdns(NULL),
-    request (NULL),
-    reply (NULL),
+    dst_rdns(nullptr),
+    request (nullptr),
+    reply (nullptr),
 #if USE_AUTH
-    auth_user_request (NULL),
+    auth_user_request (nullptr),
 #endif
 #if SQUID_SNMP
-    snmp_community(NULL),
-#endif
-#if USE_OPENSSL
-    sslErrors(NULL),
+    snmp_community(nullptr),
 #endif
     requestErrorType(ERR_MAX),
-    conn_(NULL),
+    conn_(nullptr),
     fd_(-1),
     destinationDomainChecked_(false),
     sourceDomainChecked_(false)
@@ -60,11 +58,7 @@ ACLFilledChecklist::~ACLFilledChecklist()
 
     cbdataReferenceDone(conn_);
 
-#if USE_OPENSSL
-    cbdataReferenceDone(sslErrors);
-#endif
-
-    debugs(28, 4, HERE << "ACLFilledChecklist destroyed " << this);
+    debugs(28, 4, "ACLFilledChecklist destroyed " << this);
 }
 
 static void
@@ -75,7 +69,7 @@ showDebugWarning(const char *msg)
         return;
 
     ++count;
-    debugs(28, DBG_IMPORTANT, "ALE missing " << msg);
+    debugs(28, Important(58), "ERROR: ALE missing " << msg);
 }
 
 void
@@ -146,12 +140,20 @@ ACLFilledChecklist::conn() const
 }
 
 void
-ACLFilledChecklist::conn(ConnStateData *aConn)
+ACLFilledChecklist::setConn(ConnStateData *aConn)
 {
-    if (conn() == aConn)
-        return;
-    assert (conn() == NULL);
+    if (conn_ == aConn)
+        return; // no new information
+
+    // no conn_ replacement/removal to reduce inconsistent fill concerns
+    assert(!conn_);
+    assert(aConn);
+
+    // To reduce inconsistent fill concerns, we should be the only ones calling
+    // fillConnectionLevelDetails(). Set conn_ first so that the filling method
+    // can detect (some) direct calls from others.
     conn_ = cbdataReference(aConn);
+    aConn->fillConnectionLevelDetails(*this);
 }
 
 int
@@ -210,20 +212,17 @@ ACLFilledChecklist::markSourceDomainChecked()
  *    checkCallback() will delete the list (i.e., self).
  */
 ACLFilledChecklist::ACLFilledChecklist(const acl_access *A, HttpRequest *http_request, const char *ident):
-    dst_rdns(NULL),
-    request(NULL),
-    reply(NULL),
+    dst_rdns(nullptr),
+    request(nullptr),
+    reply(nullptr),
 #if USE_AUTH
-    auth_user_request(NULL),
+    auth_user_request(nullptr),
 #endif
 #if SQUID_SNMP
-    snmp_community(NULL),
-#endif
-#if USE_OPENSSL
-    sslErrors(NULL),
+    snmp_community(nullptr),
 #endif
     requestErrorType(ERR_MAX),
-    conn_(NULL),
+    conn_(nullptr),
     fd_(-1),
     destinationDomainChecked_(false),
     sourceDomainChecked_(false)
@@ -252,8 +251,8 @@ void ACLFilledChecklist::setRequest(HttpRequest *httpRequest)
             src_addr = request->client_addr;
         my_addr = request->my_addr;
 
-        if (request->clientConnectionManager.valid())
-            conn(request->clientConnectionManager.get());
+        if (const auto cmgr = request->clientConnectionManager.get())
+            setConn(cmgr);
     }
 }
 
@@ -264,6 +263,8 @@ ACLFilledChecklist::setIdent(const char *ident)
     assert(!rfc931[0]);
     if (ident)
         xstrncpy(rfc931, ident, USER_IDENT_SZ);
+#else
+    (void)ident;
 #endif
 }
 
