@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_ACLFILLED_CHECKLIST_H
-#define SQUID_ACLFILLED_CHECKLIST_H
+#ifndef SQUID_SRC_ACL_FILLEDCHECKLIST_H
+#define SQUID_SRC_ACL_FILLEDCHECKLIST_H
 
 #include "AccessLogEntry.h"
 #include "acl/Checklist.h"
@@ -125,5 +125,5 @@ ACLFilledChecklist *Filled(ACLChecklist *checklist)
     return dynamic_cast<ACLFilledChecklist*>(checklist);
 }
 
-#endif /* SQUID_ACLFILLED_CHECKLIST_H */
+#endif /* SQUID_SRC_ACL_FILLEDCHECKLIST_H */
 
