@@ -23,18 +23,20 @@ ACLHasComponentData::ACLHasComponentData()
 void
 ACLHasComponentData::parse()
 {
-    const char *tok = ConfigParser::NextToken();
+    const auto tok = ConfigParser::strtokFile();
     if (!tok) {
         debugs(28, DBG_CRITICAL, "FATAL: \"has\" acl argument missing");
         self_destruct();
         return;
     }
-    if (ConfigParser::PeekAtToken()) {
+
+    parseComponent(tok);
+
+    if (ConfigParser::strtokFile()) {
         debugs(28, DBG_CRITICAL, "FATAL: multiple components not supported for \"has\" acl");
         self_destruct();
         return;
     }
-    parseComponent(tok);
 }
 
 bool
@@ -74,9 +76,3 @@ ACLHasComponentData::parseComponent(const char *token)
     }
 }
 
-ACLData<ACLChecklist *> *
-ACLHasComponentData::clone() const
-{
-    return new ACLHasComponentData(*this);
-}
-
