@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_ACLHASCOMPONENTDATA_H
-#define SQUID_ACLHASCOMPONENTDATA_H
+#ifndef SQUID_SRC_ACL_HASCOMPONENTDATA_H
+#define SQUID_SRC_ACL_HASCOMPONENTDATA_H
 
 #include "acl/Checklist.h"
 #include "acl/Data.h"
@@ -39,5 +39,5 @@ private:
     std::vector<ComponentCheck> componentMethods;
 };
 
-#endif
+#endif /* SQUID_SRC_ACL_HASCOMPONENTDATA_H */
 
