@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_ACLHTTPREQHEADER_H
-#define SQUID_ACLHTTPREQHEADER_H
+#ifndef SQUID_SRC_ACL_HTTPREQHEADER_H
+#define SQUID_SRC_ACL_HTTPREQHEADER_H
 
 #include "acl/Strategy.h"
 #include "HttpHeader.h"
@@ -21,5 +21,5 @@ public:
     bool requiresRequest() const override { return true; }
 };
 
-#endif /* SQUID_ACLHTTPREQHEADER_H */
+#endif /* SQUID_SRC_ACL_HTTPREQHEADER_H */
 
