@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_ACLMAXCONNECTION_H
-#define SQUID_ACLMAXCONNECTION_H
+#ifndef SQUID_SRC_ACL_MAXCONNECTION_H
+#define SQUID_SRC_ACL_MAXCONNECTION_H
 
 #include "acl/Acl.h"
 
@@ -33,5 +33,5 @@ protected:
     int limit;
 };
 
-#endif /* SQUID_ACLMAXCONNECTION_H */
+#endif /* SQUID_SRC_ACL_MAXCONNECTION_H */
 
