@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_ACLMETHOD_H
-#define SQUID_ACLMETHOD_H
+#ifndef SQUID_SRC_ACL_METHOD_H
+#define SQUID_SRC_ACL_METHOD_H
 
 #include "acl/Strategy.h"
 #include "http/RequestMethod.h"
@@ -21,5 +21,5 @@ public:
     bool requiresRequest() const override {return true;}
 };
 
-#endif /* SQUID_ACLMETHOD_H */
+#endif /* SQUID_SRC_ACL_METHOD_H */
 
