@@ -12,14 +12,9 @@
 #include "acl/Checklist.h"
 #include "acl/ProtocolData.h"
 #include "ConfigParser.h"
-#include "Debug.h"
+#include "debug/Stream.h"
 #include "wordlist.h"
 
-ACLProtocolData::ACLProtocolData(ACLProtocolData const &old)
-{
-    assert(old.values.empty());
-}
-
 ACLProtocolData::~ACLProtocolData()
 {
     values.clear();
@@ -68,11 +63,3 @@ ACLProtocolData::parse()
     }
 }
 
-ACLData<AnyP::ProtocolType> *
-ACLProtocolData::clone() const
-{
-    /* Splay trees don't clone yet. */
-    assert(values.empty());
-    return new ACLProtocolData(*this);
-}
-
