@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_ACL_RANDOM_H
-#define SQUID_ACL_RANDOM_H
+#ifndef SQUID_SRC_ACL_RANDOM_H
+#define SQUID_SRC_ACL_RANDOM_H
 
 #include "acl/Acl.h"
 
@@ -32,5 +32,5 @@ protected:
     char const *class_;
 };
 
-#endif /* SQUID_ACL_RANDOM_H */
+#endif /* SQUID_SRC_ACL_RANDOM_H */
 
