@@ -19,20 +19,26 @@
 #include "acl/Checklist.h"
 #include "acl/RegexData.h"
 #include "base/RegexPattern.h"
+#include "cache_cf.h"
 #include "ConfigParser.h"
-#include "Debug.h"
+#include "debug/Stream.h"
 #include "sbuf/Algorithms.h"
 #include "sbuf/List.h"
+#include "sbuf/Stream.h"
+
+Acl::BooleanOptionValue ACLRegexData::CaseInsensitive_;
 
 ACLRegexData::~ACLRegexData()
 {
 }
 
-const Acl::ParameterFlags &
-ACLRegexData::supportedFlags() const
+const Acl::Options &
+ACLRegexData::lineOptions()
 {
-    static const Acl::ParameterFlags flags = { "-i", "+i" };
-    return flags;
+    static auto MyCaseSensitivityOption = Acl::CaseSensitivityOption();
+    static const Acl::Options MyOptions = { &MyCaseSensitivityOption };
+    MyCaseSensitivityOption.linkWith(&CaseInsensitive_);
+    return MyOptions;
 }
 
 bool
@@ -46,7 +52,7 @@ ACLRegexData::match(char const *word)
     // walk the list of patterns to see if one matches
     for (auto &i : data) {
         if (i.match(word)) {
-            debugs(28, 2, '\'' << i.c_str() << "' found in '" << word << '\'');
+            debugs(28, 2, '\'' << i << "' found in '" << word << '\'');
             // TODO: old code also popped the pattern to second place of the list
             // in order to reduce patterns search times.
             return 1;
@@ -59,25 +65,15 @@ ACLRegexData::match(char const *word)
 SBufList
 ACLRegexData::dump() const
 {
-    SBufList sl;
-    int flags = REG_EXTENDED | REG_NOSUB;
+    SBufStream os;
 
-    // walk and dump the list
-    // keeping the flags values consistent
-    for (auto &i : data) {
-        if (i.flags != flags) {
-            if ((i.flags&REG_ICASE) != 0) {
-                sl.emplace_back("-i");
-            } else {
-                sl.emplace_back("+i");
-            }
-            flags = i.flags;
-        }
-
-        sl.emplace_back(i.c_str());
+    const RegexPattern *previous = nullptr;
+    for (const auto &i: data) {
+        i.print(os, previous); // skip flags implied by the previous entry
+        previous = &i;
     }
 
-    return sl;
+    return SBufList(1, os.buf());
 }
 
 static const char *
@@ -111,51 +107,34 @@ removeUnnecessaryWildcards(char * t)
     return t;
 }
 
-static bool
-compileRE(std::list<RegexPattern> &curlist, const char * RE, int flags)
+static void
+compileRE(std::list<RegexPattern> &curlist, const SBuf &RE, int flags)
 {
-    if (RE == NULL || *RE == '\0')
-        return curlist.empty(); // XXX: old code did this. It looks wrong.
-
-    regex_t comp;
-    if (int errcode = regcomp(&comp, RE, flags)) {
-        char errbuf[256];
-        regerror(errcode, &comp, errbuf, sizeof errbuf);
-        debugs(28, DBG_CRITICAL, cfg_filename << " line " << config_lineno << ": " << config_input_line);
-        debugs(28, DBG_CRITICAL, "ERROR: invalid regular expression: '" << RE << "': " << errbuf);
-        return false;
-    }
-    debugs(28, 2, "compiled '" << RE << "' with flags " << flags);
-
-    curlist.emplace_back(flags, RE);
-    curlist.back().regex = comp;
-
-    return true;
+    curlist.emplace_back(RE, flags);
 }
 
-static bool
-compileRE(std::list<RegexPattern> &curlist, const SBufList &RE, int flags)
+static void
+compileREs(std::list<RegexPattern> &curlist, const SBufList &RE, int flags)
 {
-    if (RE.empty())
-        return curlist.empty(); // XXX: old code did this. It looks wrong.
+    assert(!RE.empty());
     SBuf regexp;
     static const SBuf openparen("("), closeparen(")"), separator(")|(");
     JoinContainerIntoSBuf(regexp, RE.begin(), RE.end(), separator, openparen,
                           closeparen);
-    return compileRE(curlist, regexp.c_str(), flags);
+    compileRE(curlist, regexp, flags);
 }
 
 /** Compose and compile one large RE from a set of (small) REs.
  * The ultimate goal is to have only one RE per ACL so that match() is
  * called only once per ACL.
  */
-static int
-compileOptimisedREs(std::list<RegexPattern> &curlist, const SBufList &sl)
+static void
+compileOptimisedREs(std::list<RegexPattern> &curlist, const SBufList &sl, const int flagsAtLineStart)
 {
     std::list<RegexPattern> newlist;
     SBufList accumulatedRE;
     int numREs = 0, reSize = 0;
-    int flags = REG_EXTENDED | REG_NOSUB;
+    auto flags = flagsAtLineStart;
 
     for (const SBuf & configurationLineWord : sl) {
         static const SBuf minus_i("-i");
@@ -166,11 +145,12 @@ compileOptimisedREs(std::list<RegexPattern> &curlist, const SBufList &sl)
                 debugs(28, 2, "optimisation of -i ... -i" );
             } else {
                 debugs(28, 2, "-i" );
-                if (!compileRE(newlist, accumulatedRE, flags))
-                    return 0;
+                if (!accumulatedRE.empty()) {
+                    compileREs(newlist, accumulatedRE, flags);
+                    accumulatedRE.clear();
+                    reSize = 0;
+                }
                 flags |= REG_ICASE;
-                accumulatedRE.clear();
-                reSize = 0;
             }
             continue;
         } else if (configurationLineWord == plus_i) {
@@ -179,11 +159,12 @@ compileOptimisedREs(std::list<RegexPattern> &curlist, const SBufList &sl)
                 debugs(28, 2, "optimisation of +i ... +i");
             } else {
                 debugs(28, 2, "+i");
-                if (!compileRE(newlist, accumulatedRE, flags))
-                    return 0;
+                if (!accumulatedRE.empty()) {
+                    compileREs(newlist, accumulatedRE, flags);
+                    accumulatedRE.clear();
+                    reSize = 0;
+                }
                 flags &= ~REG_ICASE;
-                accumulatedRE.clear();
-                reSize = 0;
             }
             continue;
         }
@@ -195,19 +176,18 @@ compileOptimisedREs(std::list<RegexPattern> &curlist, const SBufList &sl)
 
         if (reSize > 1024) { // must be < BUFSIZ everything included
             debugs(28, 2, "buffer full, generating new optimised RE..." );
-            if (!compileRE(newlist, accumulatedRE, flags))
-                return 0;
+            compileREs(newlist, accumulatedRE, flags);
             accumulatedRE.clear();
             reSize = 0;
             continue;    /* do the loop again to add the RE to largeRE */
         }
     }
 
-    if (!compileRE(newlist, accumulatedRE, flags))
-        return 0;
-
-    accumulatedRE.clear();
-    reSize = 0;
+    if (!accumulatedRE.empty()) {
+        compileREs(newlist, accumulatedRE, flags);
+        accumulatedRE.clear();
+        reSize = 0;
+    }
 
     /* all was successful, so put the new list at the tail */
     curlist.splice(curlist.end(), newlist);
@@ -218,25 +198,21 @@ compileOptimisedREs(std::list<RegexPattern> &curlist, const SBufList &sl)
         debugs(28, (opt_parse_cfg_only?DBG_IMPORTANT:2), "WARNING: there are more than 100 regular expressions. " <<
                "Consider using less REs or use rules without expressions like 'dstdomain'.");
     }
-
-    return 1;
 }
 
 static void
-compileUnoptimisedREs(std::list<RegexPattern> &curlist, const SBufList &sl)
+compileUnoptimisedREs(std::list<RegexPattern> &curlist, const SBufList &sl, const int flagsAtLineStart)
 {
-    int flags = REG_EXTENDED | REG_NOSUB;
+    auto flags = flagsAtLineStart;
 
     static const SBuf minus_i("-i"), plus_i("+i");
-    for (auto configurationLineWord : sl) {
+    for (const auto &configurationLineWord: sl) {
         if (configurationLineWord == minus_i) {
             flags |= REG_ICASE;
         } else if (configurationLineWord == plus_i) {
             flags &= ~REG_ICASE;
         } else {
-            if (!compileRE(curlist, configurationLineWord.c_str(), flags))
-                debugs(28, DBG_CRITICAL, "ERROR: Skipping regular expression. "
-                       "Compile failed: '" << configurationLineWord << "'");
+            compileRE(curlist, configurationLineWord, flags);
         }
     }
 }
@@ -246,21 +222,30 @@ ACLRegexData::parse()
 {
     debugs(28, 2, "new Regex line or file");
 
+    int flagsAtLineStart = REG_EXTENDED | REG_NOSUB;
+    if (CaseInsensitive_)
+        flagsAtLineStart |= REG_ICASE;
+
     SBufList sl;
     while (char *t = ConfigParser::RegexStrtokFile()) {
         const char *clean = removeUnnecessaryWildcards(t);
-        if (strlen(clean) > BUFSIZ-1) {
-            debugs(28, DBG_CRITICAL, cfg_filename << " line " << config_lineno << ": " << config_input_line);
-            debugs(28, DBG_CRITICAL, "ERROR: Skipping regular expression. Larger than " << BUFSIZ-1 << " characters: '" << clean << "'");
-        } else {
-            debugs(28, 3, "buffering RE '" << clean << "'");
-            sl.emplace_back(clean);
-        }
+        debugs(28, 3, "buffering RE '" << clean << "'");
+        sl.emplace_back(clean);
     }
 
-    if (!compileOptimisedREs(data, sl)) {
-        debugs(28, DBG_IMPORTANT, "WARNING: optimisation of regular expressions failed; using fallback method without optimisation");
-        compileUnoptimisedREs(data, sl);
+    try {
+        // ignore the danger of merging invalid REs into a valid "optimized" RE
+        compileOptimisedREs(data, sl, flagsAtLineStart);
+    } catch (...) {
+        compileUnoptimisedREs(data, sl, flagsAtLineStart);
+        // Delay compileOptimisedREs() failure reporting until we know that
+        // compileUnoptimisedREs() above have succeeded. If
+        // compileUnoptimisedREs() also fails, then the compileOptimisedREs()
+        // exception caught earlier was probably not related to _optimization_
+        // (and we do not want to report the same RE compilation problem twice).
+        debugs(28, DBG_IMPORTANT, "WARNING: Failed to optimize a set of regular expressions; will use them as-is instead;" <<
+               Debug::Extra << "configuration: " << cfg_filename << " line " << config_lineno << ": " << config_input_line <<
+               Debug::Extra << "optimization error: " << CurrentException);
     }
 }
 
@@ -270,11 +255,3 @@ ACLRegexData::empty() const
     return data.empty();
 }
 
-ACLData<char const *> *
-ACLRegexData::clone() const
-{
-    /* Regex's don't clone yet. */
-    assert(data.empty());
-    return new ACLRegexData;
-}
-
