@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_ACLREPLYMIMETYPE_H
-#define SQUID_ACLREPLYMIMETYPE_H
+#ifndef SQUID_SRC_ACL_REPLYMIMETYPE_H
+#define SQUID_SRC_ACL_REPLYMIMETYPE_H
 
 #include "acl/Data.h"
 #include "acl/FilledChecklist.h"
@@ -21,11 +21,11 @@ ACLReplyHeaderStrategy<Http::HdrType::CONTENT_TYPE>::match(ACLData<char const *>
 {
     char const *theHeader = checklist->reply->header.getStr(Http::HdrType::CONTENT_TYPE);
 
-    if (NULL == theHeader)
+    if (nullptr == theHeader)
         theHeader = "";
 
     return data->match(theHeader);
 }
 
-#endif /* SQUID_ACLREPLYMIMETYPE_H */
+#endif /* SQUID_SRC_ACL_REPLYMIMETYPE_H */
 
