@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_ACLSERVERCERTIFICATE_H
-#define SQUID_ACLSERVERCERTIFICATE_H
+#ifndef SQUID_SRC_ACL_SERVERCERTIFICATE_H
+#define SQUID_SRC_ACL_SERVERCERTIFICATE_H
 
 #include "acl/Acl.h"
 #include "acl/Checklist.h"
@@ -19,8 +19,8 @@
 class ACLServerCertificateStrategy : public ACLStrategy<X509 *>
 {
 public:
-    virtual int match (ACLData<MatchType> * &, ACLFilledChecklist *) override;
+    int match (ACLData<MatchType> * &, ACLFilledChecklist *) override;
 };
 
-#endif /* SQUID_ACLSERVERCERTIFICATE_H */
+#endif /* SQUID_SRC_ACL_SERVERCERTIFICATE_H */
 
