@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_ACL_SOURCEASN_H
-#define SQUID_ACL_SOURCEASN_H
+#ifndef SQUID_SRC_ACL_SOURCEASN_H
+#define SQUID_SRC_ACL_SOURCEASN_H
 
 #include "acl/Strategy.h"
 #include "ip/Address.h"
@@ -18,8 +18,8 @@ class ACLSourceASNStrategy : public ACLStrategy<Ip::Address>
 {
 
 public:
-    virtual int match (ACLData<MatchType> * &, ACLFilledChecklist *) override;
+    int match (ACLData<MatchType> * &, ACLFilledChecklist *) override;
 };
 
-#endif /* SQUID_ACL_SOURCEASN_H */
+#endif /* SQUID_SRC_ACL_SOURCEASN_H */
 
