@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_ACLSOURCEDOMAIN_H
-#define SQUID_ACLSOURCEDOMAIN_H
+#ifndef SQUID_SRC_ACL_SOURCEDOMAIN_H
+#define SQUID_SRC_ACL_SOURCEDOMAIN_H
 #include "acl/Acl.h"
 #include "acl/Checklist.h"
 #include "acl/Data.h"
@@ -18,7 +18,7 @@ class ACLSourceDomainStrategy : public ACLStrategy<char const *>
 {
 
 public:
-    virtual int match (ACLData<MatchType> * &, ACLFilledChecklist *) override;
+    int match (ACLData<MatchType> * &, ACLFilledChecklist *) override;
 };
 
 class SourceDomainLookup : public ACLChecklist::AsyncState
@@ -26,12 +26,12 @@ class SourceDomainLookup : public ACLChecklist::AsyncState
 
 public:
     static SourceDomainLookup *Instance();
-    virtual void checkForAsync(ACLChecklist *)const;
+    void checkForAsync(ACLChecklist *)const override;
 
 private:
     static SourceDomainLookup instance_;
     static void LookupDone(const char *, const Dns::LookupDetails &, void *);
 };
 
-#endif /* SQUID_ACLSOURCEDOMAIN_H */
+#endif /* SQUID_SRC_ACL_SOURCEDOMAIN_H */
 
