@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_ACLSSL_ERROR_H
-#define SQUID_ACLSSL_ERROR_H
+#ifndef SQUID_SRC_ACL_SSLERROR_H
+#define SQUID_SRC_ACL_SSLERROR_H
 
 #include "acl/Strategy.h"
 #include "security/forward.h"
@@ -19,5 +19,5 @@ public:
     int match (ACLData<MatchType> * &, ACLFilledChecklist *) override;
 };
 
-#endif /* SQUID_ACLSSL_ERROR_H */
+#endif /* SQUID_SRC_ACL_SSLERROR_H */
 
