@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_ACLTAG_H
-#define SQUID_ACLTAG_H
+#ifndef SQUID_SRC_ACL_TAG_H
+#define SQUID_SRC_ACL_TAG_H
 
 #include "acl/Strategy.h"
 
@@ -18,5 +18,5 @@ public:
     int match (ACLData<MatchType> * &, ACLFilledChecklist *) override;
 };
 
-#endif /* SQUID_ACLMYPORTNAME_H */
+#endif /* SQUID_SRC_ACL_TAG_H */
 
