@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_ACLURL_H
-#define SQUID_ACLURL_H
+#ifndef SQUID_SRC_ACL_URL_H
+#define SQUID_SRC_ACL_URL_H
 
 #include "acl/Data.h"
 #include "acl/Strategised.h"
@@ -16,9 +16,9 @@ class ACLUrlStrategy : public ACLStrategy<char const *>
 {
 
 public:
-    virtual int match (ACLData<char const *> * &, ACLFilledChecklist *);
-    virtual bool requiresRequest() const {return true;}
+    int match (ACLData<char const *> * &, ACLFilledChecklist *) override;
+    bool requiresRequest() const override {return true;}
 };
 
-#endif /* SQUID_ACLURL_H */
+#endif /* SQUID_SRC_ACL_URL_H */
 
