@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_ACLUSERDATA_H
-#define SQUID_ACLUSERDATA_H
+#ifndef SQUID_SRC_ACL_USERDATA_H
+#define SQUID_SRC_ACL_USERDATA_H
 
 #include "acl/Acl.h"
 #include "acl/Data.h"
@@ -44,5 +44,5 @@ private:
 
 };
 
-#endif /* SQUID_ACLUSERDATA_H */
+#endif /* SQUID_SRC_ACL_USERDATA_H */
 
