@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_ACL_FORWARD_H
-#define SQUID_ACL_FORWARD_H
+#ifndef SQUID_SRC_ACL_FORWARD_H
+#define SQUID_SRC_ACL_FORWARD_H
 
 #include "base/RefCount.h"
 
@@ -48,5 +48,5 @@ typedef void ACLCB(Acl::Answer, void *);
 class ExternalACLEntry;
 typedef RefCount<ExternalACLEntry> ExternalACLEntryPointer;
 
-#endif /* SQUID_ACL_FORWARD_H */
+#endif /* SQUID_SRC_ACL_FORWARD_H */
 
