@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_ADAPTATION__ELEMENTS_H
-#define SQUID_ADAPTATION__ELEMENTS_H
+#ifndef SQUID_SRC_ADAPTATION_ELEMENTS_H
+#define SQUID_SRC_ADAPTATION_ELEMENTS_H
 
 // widely used adaptation primitives
 
@@ -24,5 +24,5 @@ const char *vectPointStr(VectPoint); // TODO: make into a stream op?
 
 } // namespace Adaptation
 
-#endif /* SQUID_ADAPTATION_ELEMENTS_H */
+#endif /* SQUID_SRC_ADAPTATION_ELEMENTS_H */
 
