@@ -8,8 +8,8 @@
 
 /* DEBUG: section 93    eCAP Interface */
 
-#ifndef SQUID_ECAP_HOST_H
-#define SQUID_ECAP_HOST_H
+#ifndef SQUID_SRC_ADAPTATION_ECAP_HOST_H
+#define SQUID_SRC_ADAPTATION_ECAP_HOST_H
 
 #include <libecap/host/host.h>
 
@@ -53,5 +53,5 @@ extern const libecap::Name metaBypassable; ///< an ecap_service parameter
 } // namespace Ecap
 } // namespace Adaptation
 
-#endif /* SQUID_ECAP_HOST_H */
+#endif /* SQUID_SRC_ADAPTATION_ECAP_HOST_H */
 
