@@ -24,7 +24,6 @@
 #include "HttpReply.h"
 #include "HttpRequest.h"
 #include "MasterXaction.h"
-#include "SquidTime.h"
 
 CBDATA_NAMESPACED_CLASS_INIT(Adaptation::Ecap::XactionRep, XactionRep);
 
@@ -38,7 +37,7 @@ public:
     OptionsExtractor(HttpHeader &aMeta): meta(aMeta) {}
 
     // libecap::NamedValueVisitor API
-    virtual void visit(const Name &name, const Area &value) {
+    void visit(const Name &name, const Area &value) override {
         meta.putExt(name.image().c_str(), value.toString().c_str());
     }
 
@@ -51,7 +50,7 @@ Adaptation::Ecap::XactionRep::XactionRep(
     AsyncJob("Adaptation::Ecap::XactionRep"),
     Adaptation::Initiate("Adaptation::Ecap::XactionRep"),
     theService(aService),
-    theVirginRep(virginHeader), theCauseRep(NULL),
+    theVirginRep(virginHeader), theCauseRep(nullptr),
     makingVb(opUndecided), proxyingAb(opUndecided),
     adaptHistoryId(-1),
     vbProductionFinished(false),
@@ -80,7 +79,7 @@ Adaptation::Ecap::XactionRep::master(const AdapterXaction &x)
 Adaptation::Service &
 Adaptation::Ecap::XactionRep::service()
 {
-    Must(theService != NULL);
+    Must(theService != nullptr);
     return *theService;
 }
 
@@ -96,7 +95,7 @@ Adaptation::Ecap::XactionRep::option(const libecap::Name &name) const
 
     // TODO: metaServerIp, metaAuthenticatedUser, and metaAuthenticatedGroups
 
-    // If the name is unknown, metaValue returns an emtpy area
+    // If the name is unknown, metaValue returns an empty area
     return metaValue(name);
 }
 
@@ -151,7 +150,7 @@ Adaptation::Ecap::XactionRep::usernameValue() const
     const HttpRequest *request = dynamic_cast<const HttpRequest*>(theCauseRep ?
                                  theCauseRep->raw().header : theVirginRep.raw().header);
     Must(request);
-    if (request->auth_user_request != NULL) {
+    if (request->auth_user_request != nullptr) {
         if (char const *name = request->auth_user_request->username())
             return libecap::Area::FromTempBuffer(name, strlen(name));
         else if (request->extacl_user.size() > 0)
@@ -163,14 +162,14 @@ Adaptation::Ecap::XactionRep::usernameValue() const
 }
 
 const libecap::Area
-Adaptation::Ecap::XactionRep::masterxSharedValue(const libecap::Name &name) const
+Adaptation::Ecap::XactionRep::masterxSharedValue(const libecap::Name &sharedName) const
 {
     const HttpRequest *request = dynamic_cast<const HttpRequest*>(theCauseRep ?
                                  theCauseRep->raw().header : theVirginRep.raw().header);
     Must(request);
-    if (name.known()) { // must check to avoid empty names matching unset cfg
+    if (sharedName.known()) { // must check to avoid empty names matching unset cfg
         Adaptation::History::Pointer ah = request->adaptHistory(false);
-        if (ah != NULL) {
+        if (ah != nullptr) {
             String name, value;
             if (ah->getXxRecord(name, value))
                 return libecap::Area::FromTempBuffer(value.rawBuf(), value.size());
@@ -188,7 +187,6 @@ Adaptation::Ecap::XactionRep::metaValue(const libecap::Name &name) const
     HttpReply *reply = dynamic_cast<HttpReply*>(theVirginRep.raw().header);
 
     if (name.known()) { // must check to avoid empty names matching unset cfg
-        typedef Notes::iterator ACAMLI;
         for (auto h: Adaptation::Config::metaHeaders) {
             if (name == h->key().toStdString()) {
                 SBuf matched;
@@ -236,13 +234,13 @@ Adaptation::Ecap::XactionRep::start()
     HttpReply *reply = dynamic_cast<HttpReply*>(theVirginRep.raw().header);
 
     Adaptation::History::Pointer ah = request->adaptLogHistory();
-    if (ah != NULL) {
+    if (ah != nullptr) {
         // retrying=false because ecap never retries transactions
         adaptHistoryId = ah->recordXactStart(service().cfg().key, current_time, false);
         SBuf matched;
         for (auto h: Adaptation::Config::metaHeaders) {
             if (h->match(request, reply, al, matched)) {
-                if (ah->metaHeaders == NULL)
+                if (ah->metaHeaders == nullptr)
                     ah->metaHeaders = new NotePairs();
                 if (!ah->metaHeaders->hasPair(h->key(), matched))
                     ah->metaHeaders->add(h->key(), matched);
@@ -261,14 +259,14 @@ Adaptation::Ecap::XactionRep::swanSong()
 
     if (theAnswerRep) {
         BodyPipe::Pointer body_pipe = answer().body_pipe;
-        if (body_pipe != NULL) {
+        if (body_pipe != nullptr) {
             Must(body_pipe->stillProducing(this));
             stopProducingFor(body_pipe, false);
         }
     }
 
     BodyPipe::Pointer &body_pipe = theVirginRep.raw().body_pipe;
-    if (body_pipe != NULL && body_pipe->stillConsuming(this))
+    if (body_pipe != nullptr && body_pipe->stillConsuming(this))
         stopConsumingFrom(body_pipe);
 
     terminateMaster();
@@ -277,7 +275,7 @@ Adaptation::Ecap::XactionRep::swanSong()
                                  theCauseRep->raw().header : theVirginRep.raw().header);
     Must(request);
     Adaptation::History::Pointer ah = request->adaptLogHistory();
-    if (ah != NULL && adaptHistoryId >= 0)
+    if (ah != nullptr && adaptHistoryId >= 0)
         ah->recordXactFinish(adaptHistoryId);
 
     Adaptation::Initiate::swanSong();
@@ -311,7 +309,7 @@ Adaptation::Ecap::XactionRep::virgin()
 const libecap::Message &
 Adaptation::Ecap::XactionRep::cause()
 {
-    Must(theCauseRep != NULL);
+    Must(theCauseRep != nullptr);
     return *theCauseRep;
 }
 
@@ -351,11 +349,11 @@ Adaptation::Ecap::XactionRep::doneAll() const
 void
 Adaptation::Ecap::XactionRep::sinkVb(const char *reason)
 {
-    debugs(93,4, HERE << "sink for " << reason << "; status:" << status());
+    debugs(93,4, "sink for " << reason << "; status:" << status());
 
     // we reset raw().body_pipe when we are done, so use this one for checking
     const BodyPipePointer &permPipe = theVirginRep.raw().header->body_pipe;
-    if (permPipe != NULL)
+    if (permPipe != nullptr)
         permPipe->enableAutoConsumption();
 
     forgetVb(reason);
@@ -365,11 +363,11 @@ Adaptation::Ecap::XactionRep::sinkVb(const char *reason)
 void
 Adaptation::Ecap::XactionRep::preserveVb(const char *reason)
 {
-    debugs(93,4, HERE << "preserve for " << reason << "; status:" << status());
+    debugs(93,4, "preserve for " << reason << "; status:" << status());
 
     // we reset raw().body_pipe when we are done, so use this one for checking
     const BodyPipePointer &permPipe = theVirginRep.raw().header->body_pipe;
-    if (permPipe != NULL) {
+    if (permPipe != nullptr) {
         // if libecap consumed, we cannot preserve
         Must(!permPipe->consumedSize());
     }
@@ -381,10 +379,10 @@ Adaptation::Ecap::XactionRep::preserveVb(const char *reason)
 void
 Adaptation::Ecap::XactionRep::forgetVb(const char *reason)
 {
-    debugs(93,9, HERE << "forget vb " << reason << "; status:" << status());
+    debugs(93,9, "forget vb " << reason << "; status:" << status());
 
     BodyPipePointer &p = theVirginRep.raw().body_pipe;
-    if (p != NULL && p->stillConsuming(this))
+    if (p != nullptr && p->stillConsuming(this))
         stopConsumingFrom(p);
 
     if (makingVb == opUndecided)
@@ -396,7 +394,7 @@ Adaptation::Ecap::XactionRep::forgetVb(const char *reason)
 void
 Adaptation::Ecap::XactionRep::useVirgin()
 {
-    debugs(93,3, HERE << status());
+    debugs(93,3, status());
     Must(proxyingAb == opUndecided);
     proxyingAb = opNever;
 
@@ -414,7 +412,7 @@ Adaptation::Ecap::XactionRep::useVirgin()
 void
 Adaptation::Ecap::XactionRep::useAdapted(const libecap::shared_ptr<libecap::Message> &m)
 {
-    debugs(93,3, HERE << status());
+    debugs(93,3, status());
     Must(m);
     theAnswerRep = m;
     Must(proxyingAb == opUndecided);
@@ -431,12 +429,12 @@ Adaptation::Ecap::XactionRep::useAdapted(const libecap::shared_ptr<libecap::Mess
         MessageRep *rep = dynamic_cast<MessageRep*>(theAnswerRep.get());
         Must(rep);
         rep->tieBody(this); // sets us as a producer
-        Must(msg->body_pipe != NULL); // check tieBody
+        Must(msg->body_pipe != nullptr); // check tieBody
 
         updateHistory(msg);
         sendAnswer(Answer::Forward(msg));
 
-        debugs(93,4, HERE << "adapter will produce body" << status());
+        debugs(93,4, "adapter will produce body" << status());
         theMaster->abMake(); // libecap will produce
     }
 }
@@ -444,13 +442,13 @@ Adaptation::Ecap::XactionRep::useAdapted(const libecap::shared_ptr<libecap::Mess
 void
 Adaptation::Ecap::XactionRep::blockVirgin()
 {
-    debugs(93,3, HERE << status());
+    debugs(93,3, status());
     Must(proxyingAb == opUndecided);
     proxyingAb = opNever;
 
     sinkVb("blockVirgin");
 
-    updateHistory(NULL);
+    updateHistory(nullptr);
     sendAnswer(Answer::Block(service().cfg().key));
     Must(done());
 }
@@ -473,7 +471,7 @@ Adaptation::Ecap::XactionRep::updateHistory(Http::Message *adapted)
     // update the cross-transactional database if needed
     if (const char *xxNameStr = Adaptation::Config::masterx_shared_name) {
         Adaptation::History::Pointer ah = request->adaptHistory(true);
-        if (ah != NULL) {
+        if (ah != nullptr) {
             libecap::Name xxName(xxNameStr); // TODO: optimize?
             if (const libecap::Area val = theMaster->option(xxName))
                 ah->updateXxRecord(xxNameStr, val.toString().c_str());
@@ -482,10 +480,9 @@ Adaptation::Ecap::XactionRep::updateHistory(Http::Message *adapted)
 
     // update the adaptation plan if needed
     if (service().cfg().routing) {
-        String services;
         if (const libecap::Area services = theMaster->option(libecap::metaNextServices)) {
             Adaptation::History::Pointer ah = request->adaptHistory(true);
-            if (ah != NULL)
+            if (ah != nullptr)
                 ah->updateNextServices(services.toString().c_str());
         }
     } // TODO: else warn (occasionally!) if we got libecap::metaNextServices
@@ -494,7 +491,7 @@ Adaptation::Ecap::XactionRep::updateHistory(Http::Message *adapted)
     // If we already have stored headers from a previous adaptation transaction
     // related to the same master transction, they will be replaced.
     Adaptation::History::Pointer ah = request->adaptLogHistory();
-    if (ah != NULL) {
+    if (ah != nullptr) {
         HttpHeader meta(hoReply);
         OptionsExtractor extractor(meta);
         theMaster->visitEachOption(extractor);
@@ -520,7 +517,7 @@ Adaptation::Ecap::XactionRep::vbMake()
 {
     Must(makingVb == opUndecided);
     BodyPipePointer &p = theVirginRep.raw().body_pipe;
-    Must(p != NULL);
+    Must(p != nullptr);
     Must(p->setConsumerIfNotLate(this)); // to deliver vb, we must receive vb
     makingVb = opOn;
 }
@@ -540,7 +537,7 @@ Adaptation::Ecap::XactionRep::vbMakeMore()
     Must(makingVb == opOn); // cannot make more if done proxying
     // we cannot guarantee more vb, but we can check that there is a chance
     const BodyPipePointer &p = theVirginRep.raw().body_pipe;
-    Must(p != NULL && p->stillConsuming(this)); // we are plugged in
+    Must(p != nullptr && p->stillConsuming(this)); // we are plugged in
     Must(!p->productionEnded() && p->mayNeedMoreData()); // and may get more
 }
 
@@ -550,7 +547,7 @@ Adaptation::Ecap::XactionRep::vbContent(libecap::size_type o, libecap::size_type
     // We may not be makingVb yet. It should be OK, but see vbContentShift().
 
     const BodyPipePointer &p = theVirginRep.raw().body_pipe;
-    Must(p != NULL);
+    Must(p != nullptr);
 
     // TODO: make MemBuf use size_t?
     const size_t haveSize = static_cast<size_t>(p->buf().contentSize());
@@ -576,7 +573,7 @@ Adaptation::Ecap::XactionRep::vbContentShift(libecap::size_type n)
     // until the adapter registers as a consumer
 
     BodyPipePointer &p = theVirginRep.raw().body_pipe;
-    Must(p != NULL);
+    Must(p != nullptr);
     const size_t size = static_cast<size_t>(n); // XXX: check for overflow
     const size_t haveSize = static_cast<size_t>(p->buf().contentSize()); // TODO: make MemBuf use size_t?
     p->consume(min(size, haveSize));
@@ -588,7 +585,7 @@ Adaptation::Ecap::XactionRep::noteAbContentDone(bool atEnd)
     Must(proxyingAb == opOn && !abProductionFinished);
     abProductionFinished = true;
     abProductionAtEnd = atEnd; // store until ready to stop producing ourselves
-    debugs(93,5, HERE << "adapted body production ended");
+    debugs(93,5, "adapted body production ended");
     moveAbContent();
 }
 
@@ -613,7 +610,7 @@ Adaptation::Ecap::XactionRep::setAdaptedBodySize(const libecap::BodySize &size)
 void
 Adaptation::Ecap::XactionRep::adaptationDelayed(const libecap::Delay &d)
 {
-    debugs(93,3, HERE << "adapter needs time: " <<
+    debugs(93,3, "adapter needs time: " <<
            d.state << '/' << d.progress);
     // XXX: set timeout?
 }
@@ -626,14 +623,14 @@ Adaptation::Ecap::XactionRep::adaptationAborted()
 }
 
 void
-Adaptation::Ecap::XactionRep::noteMoreBodySpaceAvailable(RefCount<BodyPipe> bp)
+Adaptation::Ecap::XactionRep::noteMoreBodySpaceAvailable(RefCount<BodyPipe>)
 {
     Must(proxyingAb == opOn);
     moveAbContent();
 }
 
 void
-Adaptation::Ecap::XactionRep::noteBodyConsumerAborted(RefCount<BodyPipe> bp)
+Adaptation::Ecap::XactionRep::noteBodyConsumerAborted(RefCount<BodyPipe>)
 {
     Must(proxyingAb == opOn);
     stopProducingFor(answer().body_pipe, false);
@@ -643,7 +640,7 @@ Adaptation::Ecap::XactionRep::noteBodyConsumerAborted(RefCount<BodyPipe> bp)
 }
 
 void
-Adaptation::Ecap::XactionRep::noteMoreBodyDataAvailable(RefCount<BodyPipe> bp)
+Adaptation::Ecap::XactionRep::noteMoreBodyDataAvailable(RefCount<BodyPipe>)
 {
     Must(makingVb == opOn); // or we would not be registered as a consumer
     Must(theMaster);
@@ -651,7 +648,7 @@ Adaptation::Ecap::XactionRep::noteMoreBodyDataAvailable(RefCount<BodyPipe> bp)
 }
 
 void
-Adaptation::Ecap::XactionRep::noteBodyProductionEnded(RefCount<BodyPipe> bp)
+Adaptation::Ecap::XactionRep::noteBodyProductionEnded(RefCount<BodyPipe>)
 {
     Must(makingVb == opOn); // or we would not be registered as a consumer
     Must(theMaster);
@@ -660,7 +657,7 @@ Adaptation::Ecap::XactionRep::noteBodyProductionEnded(RefCount<BodyPipe> bp)
 }
 
 void
-Adaptation::Ecap::XactionRep::noteBodyProducerAborted(RefCount<BodyPipe> bp)
+Adaptation::Ecap::XactionRep::noteBodyProducerAborted(RefCount<BodyPipe>)
 {
     Must(makingVb == opOn); // or we would not be registered as a consumer
     Must(theMaster);
@@ -680,11 +677,11 @@ Adaptation::Ecap::XactionRep::moveAbContent()
 {
     Must(proxyingAb == opOn);
     const libecap::Area c = theMaster->abContent(0, libecap::nsize);
-    debugs(93,5, HERE << "up to " << c.size << " bytes");
+    debugs(93,5, "up to " << c.size << " bytes");
     if (c.size == 0 && abProductionFinished) { // no ab now and in the future
         stopProducingFor(answer().body_pipe, abProductionAtEnd);
         proxyingAb = opComplete;
-        debugs(93,5, HERE << "last adapted body data retrieved");
+        debugs(93,5, "last adapted body data retrieved");
     } else if (c.size > 0) {
         if (const size_t used = answer().body_pipe->putMoreData(c.start, c.size))
             theMaster->abContentShift(used);
