@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_ICAPOPTIONS_H
-#define SQUID_ICAPOPTIONS_H
+#ifndef SQUID_SRC_ADAPTATION_ICAP_OPTIONS_H
+#define SQUID_SRC_ADAPTATION_ICAP_OPTIONS_H
 
 #include "adaptation/icap/ServiceRep.h"
 
@@ -100,5 +100,5 @@ private:
 } // namespace Icap
 } // namespace Adaptation
 
-#endif /* SQUID_ICAPOPTIONS_H */
+#endif /* SQUID_SRC_ADAPTATION_ICAP_OPTIONS_H */
 
