@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef _SQUID_SRC_ANYP_PROTOCOLTYPE_H
-#define _SQUID_SRC_ANYP_PROTOCOLTYPE_H
+#ifndef SQUID_SRC_ANYP_PROTOCOLTYPE_H
+#define SQUID_SRC_ANYP_PROTOCOLTYPE_H
 
 #include <ostream>
 
@@ -27,7 +27,6 @@ typedef enum {
     PROTO_HTTPS,
     PROTO_COAP,
     PROTO_COAPS,
-    PROTO_GOPHER,
     PROTO_WAIS,
     PROTO_CACHE_OBJECT,
     PROTO_ICP,
@@ -62,5 +61,5 @@ operator <<(std::ostream &os, ProtocolType const &p)
 
 } // namespace AnyP
 
-#endif /* _SQUID_SRC_ANYP_PROTOCOLTYPE_H */
+#endif /* SQUID_SRC_ANYP_PROTOCOLTYPE_H */
 
