@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_AUTH_ACL_H
-#define SQUID_AUTH_ACL_H
+#ifndef SQUID_SRC_AUTH_ACL_H
+#define SQUID_SRC_AUTH_ACL_H
 
 #if USE_AUTH
 
@@ -22,5 +22,5 @@ class ACLChecklist;
 Acl::Answer AuthenticateAcl(ACLChecklist *ch);
 
 #endif /* USE_AUTH */
-#endif /* SQUID_AUTH_ACL_H */
+#endif /* SQUID_SRC_AUTH_ACL_H */
 
