@@ -1,13 +1,13 @@
 /*
- * Copyright (C) 1996-2022 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2023 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef _SQUID__SRC_AUTH_AUTHACLSTATE_H
-#define _SQUID__SRC_AUTH_AUTHACLSTATE_H
+#ifndef SQUID_SRC_AUTH_AUTHACLSTATE_H
+#define SQUID_SRC_AUTH_AUTHACLSTATE_H
 
 #if USE_AUTH
 
@@ -19,5 +19,5 @@ typedef enum {
 } AuthAclState;
 
 #endif /* USE_AUTH */
-#endif /* _SQUID__SRC_AUTH_AUTHACLSTATE_H */
+#endif /* SQUID_SRC_AUTH_AUTHACLSTATE_H */
 
