@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef _SQUID_AUTH_CREDENTIALSTATE_H
-#define _SQUID_AUTH_CREDENTIALSTATE_H
+#ifndef SQUID_SRC_AUTH_CREDENTIALSTATE_H
+#define SQUID_SRC_AUTH_CREDENTIALSTATE_H
 
 namespace Auth
 {
@@ -24,5 +24,5 @@ extern const char *CredentialState_str[];
 
 } // namespace Auth
 
-#endif /* _SQUID_AUTH_CREDENTIALSTATE_H */
+#endif /* SQUID_SRC_AUTH_CREDENTIALSTATE_H */
 
