@@ -36,7 +36,7 @@
  */
 
 /*
- * util.c   Miscellanous generic functions.
+ * util.c   Miscellaneous generic functions.
  *
  */
 
@@ -146,7 +146,7 @@ uint32_t get_ipaddr(char *host)
 
     if (good_ipaddr(host) == 0) {
         return(ipstr2long(host));
-    } else if ((hp = gethostbyname(host)) == (struct hostent *)NULL) {
+    } else if ((hp = gethostbyname(host)) == (struct hostent *)nullptr) {
         return((uint32_t)0);
     }
     return(ntohl(*(uint32_t *)hp->h_addr));
