@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef __AUTH_DIGEST_H__
-#define __AUTH_DIGEST_H__
+#ifndef SQUID_SRC_AUTH_DIGEST_CONFIG_H
+#define SQUID_SRC_AUTH_DIGEST_CONFIG_H
 
 #if HAVE_AUTH_MODULE_DIGEST
 
@@ -103,5 +103,5 @@ public:
 extern helper *digestauthenticators;
 
 #endif /* HAVE_AUTH_MODULE_DIGEST */
-#endif
+#endif /* SQUID_SRC_AUTH_DIGEST_CONFIG_H */
 
