@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef __AUTH_NTLM_H__
-#define __AUTH_NTLM_H__
+#ifndef SQUID_SRC_AUTH_NTLM_CONFIG_H
+#define SQUID_SRC_AUTH_NTLM_CONFIG_H
 
 #if HAVE_AUTH_MODULE_NTLM
 
@@ -45,5 +45,5 @@ public:
 extern statefulhelper *ntlmauthenticators;
 
 #endif /* HAVE_AUTH_MODULE_NTLM */
-#endif
+#endif /* SQUID_SRC_AUTH_NTLM_CONFIG_H */
 
