@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_AUTH_NTLM_SCHEME_H
-#define SQUID_AUTH_NTLM_SCHEME_H
+#ifndef SQUID_SRC_AUTH_NTLM_SCHEME_H
+#define SQUID_SRC_AUTH_NTLM_SCHEME_H
 
 #if HAVE_AUTH_MODULE_NTLM
 
@@ -41,5 +41,5 @@ public:
 } // namespace Auth
 
 #endif /* HAVE_AUTH_MODULE_NTLM */
-#endif /* SQUID_AUTH_NTLM_SCHEME_H */
+#endif /* SQUID_SRC_AUTH_NTLM_SCHEME_H */
 
