@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_ASYNCCALL_H
-#define SQUID_ASYNCCALL_H
+#ifndef SQUID_SRC_BASE_ASYNCCALL_H
+#define SQUID_SRC_BASE_ASYNCCALL_H
 
 #include "base/CodeContext.h"
 #include "base/InstanceId.h"
@@ -164,5 +164,5 @@ bool ScheduleCall(const char *fileName, int fileLine, const AsyncCall::Pointer &
 /** Call scheduling helper. */
 #define ScheduleCallHere(call) ScheduleCall(__FILE__, __LINE__, (call))
 
-#endif /* SQUID_ASYNCCALL_H */
+#endif /* SQUID_SRC_BASE_ASYNCCALL_H */
 
