@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_CLIENTSTREAM_FORWARD_H
-#define SQUID_CLIENTSTREAM_FORWARD_H
+#ifndef SQUID_SRC_CLIENTSTREAMFORWARD_H
+#define SQUID_SRC_CLIENTSTREAMFORWARD_H
 
 #include "enums.h" /* for clientStream_status_t */
 
@@ -34,5 +34,5 @@ typedef void CSD(clientStreamNode *, ClientHttpRequest *);
 
 typedef clientStream_status_t CSS(clientStreamNode *, ClientHttpRequest *);
 
-#endif /* SQUID_CLIENTSTREAM_FORWARD_H */
+#endif /* SQUID_SRC_CLIENTSTREAMFORWARD_H */
 
