@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef _SQUID_SRC_COMM_ACCEPT_LIMITER_H
-#define _SQUID_SRC_COMM_ACCEPT_LIMITER_H
+#ifndef SQUID_SRC_COMM_ACCEPTLIMITER_H
+#define SQUID_SRC_COMM_ACCEPTLIMITER_H
 
 #include "comm/TcpAcceptor.h"
 
@@ -51,5 +51,5 @@ private:
 
 }; // namespace Comm
 
-#endif /* _SQUID_SRC_COMM_ACCEPT_LIMITER_H */
+#endif /* SQUID_SRC_COMM_ACCEPTLIMITER_H */
 
