@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_COMM_TCPACCEPTOR_H
-#define SQUID_COMM_TCPACCEPTOR_H
+#ifndef SQUID_SRC_COMM_TCPACCEPTOR_H
+#define SQUID_SRC_COMM_TCPACCEPTOR_H
 
 #include "anyp/forward.h"
 #include "base/AsyncJob.h"
@@ -37,16 +37,16 @@ class AcceptLimiter;
  */
 class TcpAcceptor : public AsyncJob
 {
-    CBDATA_CLASS(TcpAcceptor);
+    CBDATA_CHILD(TcpAcceptor);
 
 public:
     typedef CbcPointer<Comm::TcpAcceptor> Pointer;
 
 private:
-    virtual void start();
-    virtual bool doneAll() const;
-    virtual void swanSong();
-    virtual const char *status() const;
+    void start() override;
+    bool doneAll() const override;
+    void swanSong() override;
+    const char *status() const override;
 
     TcpAcceptor(const TcpAcceptor &); // not implemented.
 
@@ -54,6 +54,7 @@ public:
     TcpAcceptor(const Comm::ConnectionPointer &conn, const char *note, const Subscription::Pointer &aSub);
     TcpAcceptor(const AnyP::PortCfgPointer &listenPort, const char *note, const Subscription::Pointer &aSub);
 
+protected:
     /** Subscribe a handler to receive calls back about new connections.
      * Unsubscribes any existing subscribed handler.
      */
@@ -80,7 +81,6 @@ public:
     /// if not the accept() will be postponed
     static bool okToAccept();
 
-protected:
     friend class AcceptLimiter;
 
 private:
@@ -100,7 +100,7 @@ private:
     static void doAccept(int fd, void *data);
 
     void acceptOne();
-    Comm::Flag oldAccept(Comm::ConnectionPointer &details);
+    bool acceptInto(Comm::ConnectionPointer &);
     void setListen();
     void handleClosure(const CommCloseCbParams &io);
     /// whether we are listening on one of the squid.conf *ports
@@ -110,5 +110,5 @@ private:
 
 } // namespace Comm
 
-#endif /* SQUID_COMM_TCPACCEPTOR_H */
+#endif /* SQUID_SRC_COMM_TCPACCEPTOR_H */
 
