@@ -21,7 +21,7 @@ rfc2671RROptPack(char *buf, size_t sz, ssize_t edns_sz)
     opt.type = RFC1035_TYPE_OPT;
     opt._class = min(edns_sz, (ssize_t)SQUID_UDP_SO_RCVBUF-1);
     opt.ttl = 0; // relevant?
-    opt.rdata = NULL;
+    opt.rdata = nullptr;
     opt.rdlength = 0;
 
     return rfc1035RRPack(buf, sz, &opt);
