@@ -6,13 +6,13 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_RFC2671_H
-#define SQUID_RFC2671_H
+#ifndef SQUID_SRC_DNS_RFC2671_H
+#define SQUID_SRC_DNS_RFC2671_H
 
 /* RFC2671 section 7 defines new RR type OPT as 41 */
 #define RFC1035_TYPE_OPT 41
 
 SQUIDCEXTERN int rfc2671RROptPack(char *buf, size_t sz, ssize_t edns_sz);
 
-#endif /* SQUID_RFC3596_H */
+#endif /* SQUID_SRC_DNS_RFC2671_H */
 
