@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_ESI_H
-#define SQUID_ESI_H
+#ifndef SQUID_SRC_ESI_ESI_H
+#define SQUID_SRC_ESI_ESI_H
 
 #include "clientStream.h"
 #include "sbuf/SBuf.h"
@@ -32,5 +32,5 @@ inline Esi::ErrorDetail Error(const char *msg) { return ErrorDetail(msg); }
 
 } // namespace Esi
 
-#endif /* SQUID_ESI_H */
+#endif /* SQUID_SRC_ESI_ESI_H */
 
