@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_FS_ROCK_REBUILD_H
-#define SQUID_FS_ROCK_REBUILD_H
+#ifndef SQUID_SRC_FS_ROCK_ROCKREBUILD_H
+#define SQUID_SRC_FS_ROCK_ROCKREBUILD_H
 
 #include "base/AsyncJob.h"
 #include "base/RunnersRegistry.h"
@@ -130,5 +130,5 @@ private:
 
 } // namespace Rock
 
-#endif /* SQUID_FS_ROCK_REBUILD_H */
+#endif /* SQUID_SRC_FS_ROCK_ROCKREBUILD_H */
 
