@@ -10,6 +10,7 @@
 
 #include "squid.h"
 
+#include "base/IoManip.h"
 #include "DiskIO/DiskIOStrategy.h"
 #include "UFSStoreState.h"
 #include "UFSStrategy.h"
@@ -58,8 +59,7 @@ Fs::Ufs::UFSStrategy::open(SwapDir * const SD, StoreEntry * const e,
                            StoreIOState::STIOCB * aCallback, void *callback_data)
 {
     assert (((UFSSwapDir *)SD)->IO == this);
-    debugs(79, 3, "fileno "<< std::setfill('0') << std::hex
-           << std::uppercase << std::setw(8) << e->swap_filen);
+    debugs(79, 3, "fileno " << asHex(e->swap_filen).upperCase().minDigits(8));
 
     /* to consider: make createstate a private UFSStrategy call */
     StoreIOState::Pointer sio = createState (SD, e, aCallback, callback_data);
@@ -96,8 +96,7 @@ Fs::Ufs::UFSStrategy::create(SwapDir * const SD, StoreEntry * const e,
     assert (((UFSSwapDir *)SD)->IO == this);
     /* Allocate a number */
     sfileno filn = ((UFSSwapDir *)SD)->mapBitAllocate();
-    debugs(79, 3, "fileno "<< std::setfill('0') <<
-           std::hex << std::uppercase << std::setw(8) << filn);
+    debugs(79, 3, "fileno " << asHex(filn).upperCase().minDigits(8));
 
     /* Shouldn't we handle a 'bitmap full' error here? */
 
