@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_FS_UFS_UFSSWAPLOGPARSER_H
-#define SQUID_FS_UFS_UFSSWAPLOGPARSER_H
+#ifndef SQUID_SRC_FS_UFS_UFSSWAPLOGPARSER_H
+#define SQUID_SRC_FS_UFS_UFSSWAPLOGPARSER_H
 
 class StoreSwapLogData;
 
@@ -41,5 +41,5 @@ public:
 
 } //namespace Ufs
 } //namespace Fs
-#endif /* SQUID_FS_UFS_UFSSWAPLOGPARSER_H */
+#endif /* SQUID_SRC_FS_UFS_UFSSWAPLOGPARSER_H */
 
