@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef _SQUID_SRC_HELPER_CHILDCONFIG_H
-#define _SQUID_SRC_HELPER_CHILDCONFIG_H
+#ifndef SQUID_SRC_HELPER_CHILDCONFIG_H
+#define SQUID_SRC_HELPER_CHILDCONFIG_H
 
 namespace Helper
 {
@@ -116,5 +116,5 @@ public:
 #define dump_HelperChildConfig(e,n,c)  storeAppendPrintf((e), "\n%s %d startup=%d idle=%d concurrency=%d\n", (n), (c).n_max, (c).n_startup, (c).n_idle, (c).concurrency)
 #define free_HelperChildConfig(dummy)  // NO.
 
-#endif /* _SQUID_SRC_HELPER_CHILDCONFIG_H */
+#endif /* SQUID_SRC_HELPER_CHILDCONFIG_H */
 
