@@ -11,6 +11,8 @@
 
 #include "http/one/forward.h"
 
+#define HTTP_REQBUF_SZ  4096
+
 namespace Http
 {
 
@@ -24,7 +26,19 @@ typedef RefCount<Http::Stream> StreamPointer;
 
 } // namespace Http
 
-// TODO move these classes into Http namespace
+// TODO move these into Http namespace
+
+typedef enum {
+    SC_NO_STORE,
+    SC_NO_STORE_REMOTE,
+    SC_MAX_AGE,
+    SC_CONTENT,
+    SC_OTHER,
+    SC_ENUM_END /* also used to mean "invalid" */
+} http_hdr_sc_type;
+
+class HttpHdrSc;
+
 class HttpRequestMethod;
 
 class HttpRequest;
