@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef _SQUID_SRC_HTTP_ONE_REQUESTPARSER_H
-#define _SQUID_SRC_HTTP_ONE_REQUESTPARSER_H
+#ifndef SQUID_SRC_HTTP_ONE_REQUESTPARSER_H
+#define SQUID_SRC_HTTP_ONE_REQUESTPARSER_H
 
 #include "http/one/Parser.h"
 #include "http/RequestMethod.h"
@@ -36,12 +36,12 @@ public:
     RequestParser &operator =(const RequestParser &) = default;
     RequestParser(RequestParser &&) = default;
     RequestParser &operator =(RequestParser &&) = default;
-    virtual ~RequestParser() {}
+    ~RequestParser() override {}
 
     /* Http::One::Parser API */
-    virtual void clear() {*this = RequestParser();}
-    virtual Http1::Parser::size_type firstLineSize() const;
-    virtual bool parse(const SBuf &aBuf);
+    void clear() override {*this = RequestParser();}
+    Http1::Parser::size_type firstLineSize() const override;
+    bool parse(const SBuf &aBuf) override;
 
     /// the HTTP method if this is a request message
     const HttpRequestMethod & method() const {return method_;}
@@ -83,5 +83,5 @@ private:
 } // namespace One
 } // namespace Http
 
-#endif /*  _SQUID_SRC_HTTP_ONE_REQUESTPARSER_H */
+#endif /* SQUID_SRC_HTTP_ONE_REQUESTPARSER_H */
 
