@@ -8,8 +8,8 @@
 
 /* DEBUG: section 37    ICMP Routines */
 
-#ifndef _INCLUDE_ICMP_H
-#define _INCLUDE_ICMP_H
+#ifndef SQUID_SRC_ICMP_ICMP_H
+#define SQUID_SRC_ICMP_ICMP_H
 
 #include "ip/Address.h"
 
@@ -109,8 +109,8 @@ protected:
      \param ttl n(129...192) : 64 >= n >= 1
      \param ttl n(193...)    : n < 255
      *
-     \bug BUG? ttl<0 can produce high hop values
-     \bug BUG? ttl>255 can produce zero or negative hop values
+     * XXX: BUG? ttl<0 can produce high hop values
+     * XXX: BUG? ttl>255 can produce zero or negative hop values
      */
     int ipHops(int ttl);
 
@@ -123,5 +123,5 @@ protected:
 #endif /* USE_ICMP */
 };
 
-#endif
+#endif /* SQUID_SRC_ICMP_ICMP_H */
 
