@@ -1,13 +1,13 @@
 /*
- * Copyright (C) 1996-2022 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2023 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef _SQUID_SRC_IP_TOOLS_H
-#define _SQUID_SRC_IP_TOOLS_H
+#ifndef SQUID_SRC_IP_TOOLS_H
+#define SQUID_SRC_IP_TOOLS_H
 
 namespace Ip
 {
@@ -26,5 +26,5 @@ extern int EnableIpv6;
 
 } // namespace Ip
 
-#endif /* _SQUID_SRC_IP_TOOLS_H */
+#endif /* SQUID_SRC_IP_TOOLS_H */
 
