@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_IPC_STRAND_SEARCH_H
-#define SQUID_IPC_STRAND_SEARCH_H
+#ifndef SQUID_SRC_IPC_STRANDSEARCH_H
+#define SQUID_SRC_IPC_STRANDSEARCH_H
 
 #include "ipc/forward.h"
 #include "ipc/QuestionerId.h"
@@ -33,5 +33,5 @@ public:
 
 } // namespace Ipc;
 
-#endif /* SQUID_IPC_STRAND_SEARCH_H */
+#endif /* SQUID_SRC_IPC_STRANDSEARCH_H */
 
