@@ -8,8 +8,8 @@
 
 /* DEBUG: section 54    Interprocess Communication */
 
-#ifndef SQUID_IPC_FORWARD_H
-#define SQUID_IPC_FORWARD_H
+#ifndef SQUID_SRC_IPC_FORWARD_H
+#define SQUID_SRC_IPC_FORWARD_H
 
 namespace Ipc
 {
@@ -26,5 +26,5 @@ class TypedMsgHdr;
 
 } // namespace Ipc
 
-#endif /* SQUID_IPC_FORWARD_H */
+#endif /* SQUID_SRC_IPC_FORWARD_H */
 
