@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_IPC_MEM_PAGE_H
-#define SQUID_IPC_MEM_PAGE_H
+#ifndef SQUID_SRC_IPC_MEM_PAGE_H
+#define SQUID_SRC_IPC_MEM_PAGE_H
 
 #include "ipc/mem/forward.h"
 
@@ -30,7 +30,7 @@ public:
 
     // safer than bool which would enable silent casts to int
     typedef const uint32_t PageId::*SaferBool;
-    operator SaferBool() const { return set() ? &PageId::number : NULL; }
+    operator SaferBool() const { return set() ? &PageId::number : nullptr; }
 
     /// The ID of a PagePool (and/or PageStack) this page belongs to.
     /// Positive values are (ab)used to detect in-use pages. See set().
@@ -52,5 +52,5 @@ std::ostream &operator <<(std::ostream &os, const PageId &page);
 
 } // namespace Ipc
 
-#endif // SQUID_IPC_MEM_PAGE_H
+#endif /* SQUID_SRC_IPC_MEM_PAGE_H */
 
