@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_IPC_MEM_FORWARD_H
-#define SQUID_IPC_MEM_FORWARD_H
+#ifndef SQUID_SRC_IPC_MEM_FORWARD_H
+#define SQUID_SRC_IPC_MEM_FORWARD_H
 
 namespace Ipc
 {
@@ -19,5 +19,5 @@ typedef uint32_t PoolId;
 
 } // namespace Ipc
 
-#endif /* SQUID_IPC_MEM_FORWARD_H */
+#endif /* SQUID_SRC_IPC_MEM_FORWARD_H */
 
