@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef _SQUID_SRC_LOG_TCPLOGGER_H
-#define _SQUID_SRC_LOG_TCPLOGGER_H
+#ifndef SQUID_SRC_LOG_TCPLOGGER_H
+#define SQUID_SRC_LOG_TCPLOGGER_H
 
 #include "base/AsyncJob.h"
 #include "base/JobWait.h"
@@ -114,5 +114,5 @@ private:
 
 } // namespace Log
 
-#endif /* _SQUID_SRC_LOG_TCPLOGGER_H */
+#endif /* SQUID_SRC_LOG_TCPLOGGER_H */
 
