@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef _SQUID_LOOKUP_T_H
-#define _SQUID_LOOKUP_T_H
+#ifndef SQUID_SRC_LOOKUP_T_H
+#define SQUID_SRC_LOOKUP_T_H
 
 typedef enum {
     LOOKUP_NONE,
@@ -17,5 +17,5 @@ typedef enum {
 
 extern const char *lookup_t_str[];
 
-#endif /* _SQUID_LOOKUP_T_H */
+#endif /* SQUID_SRC_LOOKUP_T_H */
 
