@@ -81,7 +81,7 @@
 #include "unlinkd.h"
 #include "wccp.h"
 #include "wccp2.h"
-#include "WinSvc.h"
+#include "windows_service.h"
 
 #if USE_ADAPTATION
 #include "adaptation/Config.h"
@@ -1535,6 +1535,7 @@ SquidMain(int argc, char **argv)
     WIN32_svcstatusupdate(SERVICE_START_PENDING, 10000);
 
 #endif
+    AnyP::UriScheme::Init(); // needs to be before arg parsing, bug 5337
 
     cmdLine.forEachOption(mainHandleCommandLineOption);
 
@@ -1576,8 +1577,6 @@ SquidMain(int argc, char **argv)
 
         Mem::Init();
 
-        AnyP::UriScheme::Init();
-
         storeFsInit();      /* required for config parsing */
 
         Fs::Init();
