@@ -8,8 +8,8 @@
 
 /* DEBUG: section 16    Cache Manager API */
 
-#ifndef SQUID_MGR_ACTION_H
-#define SQUID_MGR_ACTION_H
+#ifndef SQUID_SRC_MGR_ACTION_H
+#define SQUID_SRC_MGR_ACTION_H
 
 #include "ipc/forward.h"
 #include "mgr/forward.h"
@@ -92,5 +92,5 @@ private:
 
 } // namespace Mgr
 
-#endif /* SQUID_MGR_ACTION_H */
+#endif /* SQUID_SRC_MGR_ACTION_H */
 
