@@ -8,8 +8,8 @@
 
 /* DEBUG: section 16    Cache Manager API */
 
-#ifndef SQUID_MGR_INTERVAL_ACTION_H
-#define SQUID_MGR_INTERVAL_ACTION_H
+#ifndef SQUID_SRC_MGR_INTERVALACTION_H
+#define SQUID_SRC_MGR_INTERVALACTION_H
 
 #include "mgr/Action.h"
 
@@ -133,5 +133,5 @@ private:
 
 } // namespace Mgr
 
-#endif /* SQUID_MGR_INTERVAL_ACTION_H */
+#endif /* SQUID_SRC_MGR_INTERVALACTION_H */
 
