@@ -8,8 +8,8 @@
 
 /* DEBUG: section 16    Cache Manager API */
 
-#ifndef SQUID_MGR_IO_ACTION_H
-#define SQUID_MGR_IO_ACTION_H
+#ifndef SQUID_SRC_MGR_IOACTION_H
+#define SQUID_SRC_MGR_IOACTION_H
 
 #include "IoStats.h"
 #include "mgr/Action.h"
@@ -27,10 +27,8 @@ public:
 public:
     double http_reads;
     double ftp_reads;
-    double gopher_reads;
     double http_read_hist[IoStats::histSize];
     double ftp_read_hist[IoStats::histSize];
-    double gopher_read_hist[IoStats::histSize];
 };
 
 /// implement aggregated 'io' action
@@ -42,14 +40,14 @@ protected:
 public:
     static Pointer Create(const CommandPointer &cmd);
     /* Action API */
-    virtual void add(const Action& action);
-    virtual void pack(Ipc::TypedMsgHdr& msg) const;
-    virtual void unpack(const Ipc::TypedMsgHdr& msg);
+    void add(const Action& action) override;
+    void pack(Ipc::TypedMsgHdr& msg) const override;
+    void unpack(const Ipc::TypedMsgHdr& msg) override;
 
 protected:
     /* Action API */
-    virtual void collect();
-    virtual void dump(StoreEntry* entry);
+    void collect() override;
+    void dump(StoreEntry* entry) override;
 
 private:
     IoActionData data;
@@ -57,5 +55,5 @@ private:
 
 } // namespace Mgr
 
-#endif /* SQUID_MGR_IO_ACTION_H */
+#endif /* SQUID_SRC_MGR_IOACTION_H */
 
