@@ -8,8 +8,8 @@
 
 /* DEBUG: section 16    Cache Manager API */
 
-#ifndef SQUID_MGR_SERVICE_TIMES_ACTION_H
-#define SQUID_MGR_SERVICE_TIMES_ACTION_H
+#ifndef SQUID_SRC_MGR_SERVICETIMESACTION_H
+#define SQUID_SRC_MGR_SERVICETIMESACTION_H
 
 #include "mgr/Action.h"
 
@@ -68,5 +68,5 @@ private:
 
 } // namespace Mgr
 
-#endif /* SQUID_MGR_SERVICE_TIMES_ACTION_H */
+#endif /* SQUID_SRC_MGR_SERVICETIMESACTION_H */
 
