@@ -9,8 +9,9 @@
 /* DEBUG: section 25    MiME Header Parsing */
 
 #include "squid.h"
-#include "Debug.h"
-#include "profiler/Profiler.h"
+#include "debug/Stream.h"
+#include "mime_header.h"
+#include "sbuf/SBuf.h"
 
 size_t
 headersEnd(const char *mime, size_t l, bool &containsObsFold)
@@ -19,8 +20,6 @@ headersEnd(const char *mime, size_t l, bool &containsObsFold)
     int state = 1;
     containsObsFold = false;
 
-    PROF_start(headersEnd);
-
     while (e < l && state < 3) {
         switch (state) {
 
@@ -58,7 +57,6 @@ headersEnd(const char *mime, size_t l, bool &containsObsFold)
 
         ++e;
     }
-    PROF_stop(headersEnd);
 
     if (3 == state)
         return e;
@@ -66,3 +64,9 @@ headersEnd(const char *mime, size_t l, bool &containsObsFold)
     return 0;
 }
 
+size_t
+headersEnd(const SBuf &buf, bool &containsObsFold)
+{
+    return headersEnd(buf.rawContent(), buf.length(), containsObsFold);
+}
+
