@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_PARSER_FORWARD_H
-#define SQUID_PARSER_FORWARD_H
+#ifndef SQUID_SRC_PARSER_FORWARD_H
+#define SQUID_SRC_PARSER_FORWARD_H
 
 namespace Parser {
 class Tokenizer;
@@ -18,5 +18,5 @@ class BinaryTokenizer;
 class InsufficientInput {};
 } // namespace Parser
 
-#endif /* SQUID_PARSER_FORWARD_H */
+#endif /* SQUID_SRC_PARSER_FORWARD_H */
 
