@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef _SQUID_SRC_PROXYP_FORWARD_H
-#define _SQUID_SRC_PROXYP_FORWARD_H
+#ifndef SQUID_SRC_PROXYP_FORWARD_H
+#define SQUID_SRC_PROXYP_FORWARD_H
 
 #include "base/RefCount.h"
 
@@ -20,5 +20,5 @@ typedef RefCount<Header> HeaderPointer;
 
 }
 
-#endif /* _SQUID_SRC_PROXYP_FORWARD_H */
+#endif /* SQUID_SRC_PROXYP_FORWARD_H */
 
