@@ -8,8 +8,8 @@
 
 /* DEBUG: section 22    Refresh Calculation */
 
-#ifndef SQUID_REFRESH_H_
-#define SQUID_REFRESH_H_
+#ifndef SQUID_SRC_REFRESH_H
+#define SQUID_SRC_REFRESH_H
 
 class RefreshPattern;
 
@@ -23,5 +23,5 @@ time_t getMaxAge(const char *url);
 void refreshInit(void);
 const RefreshPattern *refreshLimits(const char *url);
 
-#endif /* SQUID_REFRESH_H_ */
+#endif /* SQUID_SRC_REFRESH_H */
 
