@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef _SQUIDINC_STORE_HEAP_REPLACEMENT_H
-#define _SQUIDINC_STORE_HEAP_REPLACEMENT_H
+#ifndef SQUID_SRC_REPL_HEAP_STORE_HEAP_REPLACEMENT_H
+#define SQUID_SRC_REPL_HEAP_STORE_HEAP_REPLACEMENT_H
 
 #include "heap.h"
 
@@ -15,5 +15,5 @@ heap_key HeapKeyGen_StoreEntry_LFUDA(void *entry, double age);
 heap_key HeapKeyGen_StoreEntry_GDSF(void *entry, double age);
 heap_key HeapKeyGen_StoreEntry_LRU(void *entry, double age);
 
-#endif /* _SQUIDINC_STORE_HEAP_REPLACEMENT_H */
+#endif /* SQUID_SRC_REPL_HEAP_STORE_HEAP_REPLACEMENT_H */
 
