@@ -452,7 +452,7 @@ Security::ErrorDetail::ErrorDetail(const ErrorCode err, const int aSysErrorNo):
 #if USE_OPENSSL
     /// Extract and remember errors stored internally by the TLS library.
     if ((lib_error_no = ERR_get_error())) {
-        debugs(83, 7, "got " << asHex(lib_error_no));
+        debugs(83, 7, "got 0x" << asHex(lib_error_no));
         // more errors may be stacked
         // TODO: Save/detail all stacked errors by always flushing stale ones.
         ForgetErrors();
@@ -504,7 +504,7 @@ Security::ErrorDetail::brief() const
 #if USE_OPENSSL
         // TODO: Log ERR_error_string_n() instead, despite length, whitespace?
         // Example: `error:1408F09C:SSL routines:ssl3_get_record:http request`.
-        buf.append(ToSBuf("+TLS_LIB_ERR=", std::hex, std::uppercase, lib_error_no));
+        buf.append(ToSBuf("+TLS_LIB_ERR=", asHex(lib_error_no).upperCase()));
 #elif USE_GNUTLS
         buf.append(ToSBuf("+", gnutls_strerror_name(lib_error_no)));
 #endif
