@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_SRC_SECURITY_DETAIL_H
-#define SQUID_SRC_SECURITY_DETAIL_H
+#ifndef SQUID_SRC_SECURITY_ERRORDETAIL_H
+#define SQUID_SRC_SECURITY_ERRORDETAIL_H
 
 #include "base/RefCount.h"
 #include "error/Detail.h"
@@ -138,5 +138,5 @@ operator <<(std::ostream &os, const ErrorDetail::Pointer &p)
 
 } // namespace Security
 
-#endif
+#endif /* SQUID_SRC_SECURITY_ERRORDETAIL_H */
 
