@@ -11,6 +11,7 @@
 #include "squid.h"
 #include "acl/FilledChecklist.h"
 #include "base/CharacterSet.h"
+#include "base/Raw.h"
 #include "base/RefCount.h"
 #include "base/Subscription.h"
 #include "client_side_reply.h"
@@ -96,7 +97,7 @@ Ftp::Server::start()
         char buf[MAX_IPSTRLEN];
         clientConnection->local.toUrl(buf, MAX_IPSTRLEN);
         host = buf;
-        calcUri(NULL);
+        calcUri(nullptr);
         debugs(33, 5, "FTP transparent URL: " << uri);
     }
 
@@ -107,7 +108,7 @@ Ftp::Server::start()
 void
 Ftp::Server::maybeReadUploadData()
 {
-    if (reader != NULL)
+    if (reader != nullptr)
         return;
 
     const size_t availSpace = sizeof(uploadBuf) - uploadAvailSize;
@@ -132,19 +133,19 @@ Ftp::Server::doProcessRequest()
     Must(context != nullptr);
 
     ClientHttpRequest *const http = context->http;
-    assert(http != NULL);
+    assert(http != nullptr);
 
     HttpRequest *const request = http->request;
     Must(http->storeEntry() || request);
     const bool mayForward = !http->storeEntry() && handleRequest(request);
 
-    if (http->storeEntry() != NULL) {
+    if (http->storeEntry() != nullptr) {
         debugs(33, 4, "got an immediate response");
         clientSetKeepaliveFlag(http);
         context->pullData();
     } else if (mayForward) {
         debugs(33, 4, "forwarding request to server side");
-        assert(http->storeEntry() == NULL);
+        assert(http->storeEntry() == nullptr);
         clientProcessRequest(this, Http1::RequestParserPointer(), context.getRaw());
     } else {
         debugs(33, 4, "will resume processing later");
@@ -167,13 +168,13 @@ void
 Ftp::Server::readUploadData(const CommIoCbParams &io)
 {
     debugs(33, 5, io.conn << " size " << io.size);
-    Must(reader != NULL);
-    reader = NULL;
+    Must(reader != nullptr);
+    reader = nullptr;
 
     assert(Comm::IsConnOpen(dataConn));
     assert(io.conn->fd == dataConn->fd);
 
-    if (io.flag == Comm::OK && bodyPipe != NULL) {
+    if (io.flag == Comm::OK && bodyPipe != nullptr) {
         if (io.size > 0) {
             statCounter.client_http.kbytes_in += io.size;
 
@@ -200,7 +201,7 @@ Ftp::Server::readUploadData(const CommIoCbParams &io)
 void
 Ftp::Server::shovelUploadData()
 {
-    assert(bodyPipe != NULL);
+    assert(bodyPipe != nullptr);
 
     debugs(33, 5, "handling FTP request data for " << clientConnection);
     const size_t putSize = bodyPipe->putMoreData(uploadBuf,
@@ -240,32 +241,32 @@ Ftp::Server::noteBodyConsumerAborted(BodyPipe::Pointer ptr)
 void
 Ftp::Server::AcceptCtrlConnection(const CommAcceptCbParams &params)
 {
-    MasterXaction::Pointer xact = params.xaction;
-    AnyP::PortCfgPointer s = xact->squidPort;
+    Assure(params.port);
 
     // NP: it is possible the port was reconfigured when the call or accept() was queued.
 
     if (params.flag != Comm::OK) {
         // Its possible the call was still queued when the client disconnected
-        debugs(33, 2, s->listenConn << ": FTP accept failure: " << xstrerr(params.xerrno));
+        debugs(33, 2, params.port->listenConn << ": FTP accept failure: " << xstrerr(params.xerrno));
         return;
     }
 
     debugs(33, 4, params.conn << ": accepted");
     fd_note(params.conn->fd, "client ftp connect");
 
-    if (s->tcp_keepalive.enabled)
-        commSetTcpKeepalive(params.conn->fd, s->tcp_keepalive.idle, s->tcp_keepalive.interval, s->tcp_keepalive.timeout);
-
-    ++incoming_sockets_accepted;
+    const auto xact = MasterXaction::MakePortful(params.port);
+    xact->tcpClient = params.conn;
 
     AsyncJob::Start(new Server(xact));
+    // XXX: do not abandon the MasterXaction object
 }
 
 void
 Ftp::StartListening()
 {
-    for (AnyP::PortCfgPointer s = FtpPortList; s != NULL; s = s->next) {
+    const auto savedContext = CodeContext::Current();
+    for (AnyP::PortCfgPointer s = FtpPortList; s != nullptr; s = s->next) {
+        CodeContext::Reset(s);
         if (MAXTCPLISTENPORTS == NHttpSockets) {
             debugs(1, DBG_IMPORTANT, "Ignoring ftp_port lines exceeding the" <<
                    " limit of " << MAXTCPLISTENPORTS << " ports.");
@@ -276,21 +277,25 @@ Ftp::StartListening()
         typedef CommCbFunPtrCallT<CommAcceptCbPtrFun> AcceptCall;
         RefCount<AcceptCall> subCall = commCbCall(5, 5, "Ftp::Server::AcceptCtrlConnection",
                                        CommAcceptCbPtrFun(Ftp::Server::AcceptCtrlConnection,
-                                               CommAcceptCbParams(NULL)));
+                                               CommAcceptCbParams(nullptr)));
         clientStartListeningOn(s, subCall, Ipc::fdnFtpSocket);
     }
+    CodeContext::Reset(savedContext);
 }
 
 void
 Ftp::StopListening()
 {
-    for (AnyP::PortCfgPointer s = FtpPortList; s != NULL; s = s->next) {
-        if (s->listenConn != NULL) {
+    const auto savedContext = CodeContext::Current();
+    for (AnyP::PortCfgPointer s = FtpPortList; s != nullptr; s = s->next) {
+        CodeContext::Reset(s);
+        if (s->listenConn != nullptr) {
             debugs(1, DBG_IMPORTANT, "Closing FTP port " << s->listenConn->local);
             s->listenConn->close();
-            s->listenConn = NULL;
+            s->listenConn = nullptr;
         }
     }
+    CodeContext::Reset(savedContext);
 }
 
 void
@@ -300,9 +305,9 @@ Ftp::Server::notePeerConnection(Comm::ConnectionPointer conn)
     Http::StreamPointer context = pipeline.front();
     Must(context != nullptr);
     ClientHttpRequest *const http = context->http;
-    Must(http != NULL);
+    Must(http != nullptr);
     HttpRequest *const request = http->request;
-    Must(request != NULL);
+    Must(request != nullptr);
     // make FTP peer connection exclusive to our request
     pinBusyConnection(conn, request);
 }
@@ -318,7 +323,7 @@ Ftp::Server::clientPinnedConnectionClosed(const CommCloseCbParams &io)
         clientConnection->close();
 
     // TODO: If the server control connection is gone, reset state to login
-    // again. Reseting login alone is not enough: FtpRelay::sendCommand() will
+    // again. Resetting login alone is not enough: FtpRelay::sendCommand() will
     // not re-login because FtpRelay::serverState() is not going to be
     // fssConnected. Calling resetLogin() alone is also harmful because
     // it does not reset correctly the client-to-squid control connection (eg
@@ -373,7 +378,7 @@ Ftp::Server::listenForDataConnection()
     const char *const note = uri.c_str();
     comm_open_listener(SOCK_STREAM, IPPROTO_TCP, conn, note);
     if (!Comm::IsConnOpen(conn)) {
-        debugs(5, DBG_CRITICAL, "comm_open_listener failed for FTP data: " <<
+        debugs(5, DBG_CRITICAL, "ERROR: comm_open_listener failed for FTP data: " <<
                conn->local << " error: " << errno);
         writeCustomReply(451, "Internal error");
         return 0;
@@ -381,7 +386,7 @@ Ftp::Server::listenForDataConnection()
 
     typedef CommCbMemFunT<Server, CommAcceptCbParams> AcceptDialer;
     typedef AsyncCallT<AcceptDialer> AcceptCall;
-    RefCount<AcceptCall> call = static_cast<AcceptCall*>(JobCallback(5, 5, AcceptDialer, this, Ftp::Server::acceptDataConnection));
+    const auto call = JobCallback(5, 5, AcceptDialer, this, Ftp::Server::acceptDataConnection);
     Subscription::Pointer sub = new CallSubscription<AcceptCall>(call);
     listener = call.getRaw();
     dataListenConn = conn;
@@ -404,7 +409,6 @@ Ftp::Server::acceptDataConnection(const CommAcceptCbParams &params)
 
     debugs(33, 4, "accepted " << params.conn);
     fd_note(params.conn->fd, "passive client ftp data");
-    ++incoming_sockets_accepted;
 
     if (!clientConnection) {
         debugs(33, 5, "late data connection?");
@@ -418,11 +422,12 @@ Ftp::Server::acceptDataConnection(const CommAcceptCbParams &params)
     } else {
         closeDataConnection();
         dataConn = params.conn;
+        dataConn->leaveOrphanage();
         uploadAvailSize = 0;
         debugs(33, 7, "ready for data");
-        if (onDataAcceptCall != NULL) {
+        if (onDataAcceptCall != nullptr) {
             AsyncCall::Pointer call = onDataAcceptCall;
-            onDataAcceptCall = NULL;
+            onDataAcceptCall = nullptr;
             // If we got an upload request, start reading data from the client.
             if (master->serverState == fssHandleUploadRequest)
                 maybeReadUploadData();
@@ -439,9 +444,9 @@ Ftp::Server::acceptDataConnection(const CommAcceptCbParams &params)
 void
 Ftp::Server::closeDataConnection()
 {
-    if (listener != NULL) {
+    if (listener != nullptr) {
         listener->cancel("no longer needed");
-        listener = NULL;
+        listener = nullptr;
     }
 
     if (Comm::IsConnOpen(dataListenConn)) {
@@ -449,12 +454,12 @@ Ftp::Server::closeDataConnection()
                *dataListenConn);
         dataListenConn->close();
     }
-    dataListenConn = NULL;
+    dataListenConn = nullptr;
 
-    if (reader != NULL) {
+    if (reader != nullptr) {
         // Comm::ReadCancel can deal with negative FDs
         Comm::ReadCancel(dataConn->fd, reader);
-        reader = NULL;
+        reader = nullptr;
     }
 
     if (Comm::IsConnOpen(dataConn)) {
@@ -462,7 +467,7 @@ Ftp::Server::closeDataConnection()
                *dataConn);
         dataConn->close();
     }
-    dataConn = NULL;
+    dataConn = nullptr;
 }
 
 /// Writes FTP [error] response before we fully parsed the FTP request and
@@ -504,7 +509,7 @@ Ftp::Server::writeCustomReply(const int code, const char *msg, const HttpReply *
     debugs(33, 7, code << ' ' << msg);
     assert(99 < code && code < 1000);
 
-    const bool sendDetails = reply != NULL &&
+    const bool sendDetails = reply != nullptr &&
                              reply->header.has(Http::HdrType::FTP_STATUS) && reply->header.has(Http::HdrType::FTP_REASON);
 
     MemBuf mb;
@@ -673,7 +678,7 @@ Ftp::Server::parseOneRequest()
                                          static_cast<SBuf::size_type>(Config.maxRequestHeaderSize));
     if (cmd.length() > tokenMax || params.length() > tokenMax) {
         changeState(fssError, "huge req token");
-        quitAfterError(NULL);
+        quitAfterError(nullptr);
         return earlyError(EarlyErrorKind::HugeRequest);
     }
 
@@ -682,13 +687,13 @@ Ftp::Server::parseOneRequest()
         // we need more data, but can we buffer more?
         if (inBuf.length() >= Config.maxRequestHeaderSize) {
             changeState(fssError, "huge req");
-            quitAfterError(NULL);
+            quitAfterError(nullptr);
             return earlyError(EarlyErrorKind::HugeRequest);
         } else {
             flags.readMore = true;
             debugs(33, 5, "Waiting for more, up to " <<
                    (Config.maxRequestHeaderSize - inBuf.length()));
-            return NULL;
+            return nullptr;
         }
     }
 
@@ -722,9 +727,9 @@ Ftp::Server::parseOneRequest()
         Http::METHOD_PUT : Http::METHOD_GET;
 
     const SBuf *path = (params.length() && CommandHasPathParameter(cmd)) ?
-                       &params : NULL;
+                       &params : nullptr;
     calcUri(path);
-    MasterXaction::Pointer mx = new MasterXaction(XactionInitiator::initClient);
+    const auto mx = MasterXaction::MakePortful(port);
     mx->tcpClient = clientConnection;
     auto * const request = HttpRequest::FromUrl(uri, mx, method);
     if (!request) {
@@ -738,8 +743,7 @@ Ftp::Server::parseOneRequest()
     request->http_ver = Http::ProtocolVersion(Ftp::ProtocolVersion().major, Ftp::ProtocolVersion().minor);
 
     // Our fake Request-URIs are not distinctive enough for caching to work
-    request->flags.cachable = false; // XXX: reset later by maybeCacheable()
-    request->flags.noCache = true;
+    request->flags.disableCacheUse("FTP command wrapper");
 
     request->header.putStr(Http::HdrType::FTP_COMMAND, cmd.c_str());
     request->header.putStr(Http::HdrType::FTP_ARGUMENTS, params.c_str()); // may be ""
@@ -778,8 +782,8 @@ Ftp::Server::handleReply(HttpReply *reply, StoreIOBuffer data)
     assert(context != nullptr);
 
     static ReplyHandler handlers[] = {
-        NULL, // fssBegin
-        NULL, // fssConnected
+        nullptr, // fssBegin
+        nullptr, // fssConnected
         &Ftp::Server::handleFeatReply, // fssHandleFeat
         &Ftp::Server::handlePasvReply, // fssHandlePasv
         &Ftp::Server::handlePortReply, // fssHandlePort
@@ -787,9 +791,9 @@ Ftp::Server::handleReply(HttpReply *reply, StoreIOBuffer data)
         &Ftp::Server::handleUploadReply, // fssHandleUploadRequest
         &Ftp::Server::handleEprtReply,// fssHandleEprt
         &Ftp::Server::handleEpsvReply,// fssHandleEpsv
-        NULL, // fssHandleCwd
-        NULL, // fssHandlePass
-        NULL, // fssHandleCdup
+        nullptr, // fssHandleCwd
+        nullptr, // fssHandlePass
+        nullptr, // fssHandleCdup
         &Ftp::Server::handleErrorReply // fssError
     };
     try {
@@ -838,7 +842,7 @@ Ftp::Server::handleFeatReply(const HttpReply *reply, StoreIOBuffer)
                 if (!tok.skip('"') || !tok.skip(' '))
                     continue;
 
-                // optional spaces; remember their number to accomodate MS servers
+                // optional spaces; remember their number to accommodate MS servers
                 prependSpaces = 1 + tok.skipAll(CharacterSet::SP);
 
                 SBuf cmd;
@@ -938,7 +942,7 @@ Ftp::Server::handleErrorReply(const HttpReply *reply, StoreIOBuffer)
 void
 Ftp::Server::handleDataReply(const HttpReply *reply, StoreIOBuffer data)
 {
-    if (reply != NULL && reply->sline.status() != Http::scOkay) {
+    if (reply != nullptr && reply->sline.status() != Http::scOkay) {
         writeForwardedReply(reply);
         if (Comm::IsConnOpen(dataConn)) {
             debugs(33, 3, "closing " << dataConn << " on KO reply");
@@ -1034,7 +1038,7 @@ Ftp::Server::writeForwardedReply(const HttpReply *reply)
     Must(reply);
 
     if (waitingForOrigin) {
-        Must(delayedReply == NULL);
+        Must(delayedReply == nullptr);
         delayedReply = reply;
         return;
     }
@@ -1107,7 +1111,7 @@ Ftp::Server::writeErrorReply(const HttpReply *reply, const int scode)
 #if USE_ADAPTATION
     // XXX: Remove hard coded names. Use an error page template instead.
     const Adaptation::History::Pointer ah = request->adaptHistory();
-    if (ah != NULL) { // XXX: add adapt::<all_h but use lastMeta here
+    if (ah != nullptr) { // XXX: add adapt::<all_h but use lastMeta here
         const String info = ah->allMeta.getByName("X-Response-Info");
         const String desc = ah->allMeta.getByName("X-Response-Desc");
         if (info.size())
@@ -1156,7 +1160,7 @@ Ftp::Server::writeControlMsgAndCall(HttpReply *reply, AsyncCall::Pointer &call)
 void
 Ftp::Server::writeForwardedReplyAndCall(const HttpReply *reply, AsyncCall::Pointer &call)
 {
-    assert(reply != NULL);
+    assert(reply != nullptr);
     const HttpHeader &header = reply->header;
 
     // without status, the caller must use the writeForwardedForeign() path
@@ -1222,7 +1226,7 @@ Ftp::PrintReply(MemBuf &mb, const HttpReply *reply, const char *const)
     if (header.has(Http::HdrType::FTP_STATUS)) {
         const char *reason = header.getStr(Http::HdrType::FTP_REASON);
         mb.appendf("%i %s\r\n", header.getInt(Http::HdrType::FTP_STATUS),
-                   (reason ? reason : 0));
+                   (reason ? reason : nullptr));
     }
 }
 
@@ -1331,7 +1335,7 @@ Ftp::Server::handleRequest(HttpRequest *request)
         handlers["CDUP"] = &Ftp::Server::handleCdupRequest;
     }
 
-    RequestHandler handler = NULL;
+    RequestHandler handler = nullptr;
     if (request->method == Http::METHOD_PUT)
         handler = &Ftp::Server::handleUploadRequest;
     else {
@@ -1382,7 +1386,7 @@ Ftp::Server::handleUserRequest(const SBuf &, SBuf &params)
         oldUri = uri;
 
     master->workingDir.clear();
-    calcUri(NULL);
+    calcUri(nullptr);
 
     if (!master->clientReadGreeting) {
         debugs(9, 3, "set URI to " << uri);
@@ -1395,7 +1399,7 @@ Ftp::Server::handleUserRequest(const SBuf &, SBuf &params)
         resetLogin("URI reset");
     }
 
-    return NULL; // no early errors
+    return nullptr; // no early errors
 }
 
 bool
@@ -1427,7 +1431,7 @@ Ftp::Server::handlePasvRequest(String &, String &params)
 bool
 Ftp::Server::createDataConnection(Ip::Address cltAddr)
 {
-    assert(clientConnection != NULL);
+    assert(clientConnection != nullptr);
     assert(!clientConnection->remote.isAnyAddr());
 
     if (cltAddr != clientConnection->remote) {
@@ -1499,7 +1503,7 @@ Ftp::Server::handlePortRequest(String &, String &params)
     }
 
     Ip::Address cltAddr;
-    if (!Ftp::ParseIpPort(params.termedBuf(), NULL, cltAddr)) {
+    if (!Ftp::ParseIpPort(params.termedBuf(), nullptr, cltAddr)) {
         setReply(501, "Invalid parameter");
         return false;
     }
@@ -1535,7 +1539,7 @@ Ftp::Server::handleUploadRequest(String &, String &)
     if (Config.accessList.forceRequestBodyContinuation) {
         ClientHttpRequest *http = pipeline.front()->http;
         HttpRequest *request = http->request;
-        ACLFilledChecklist bodyContinuationCheck(Config.accessList.forceRequestBodyContinuation, request, NULL);
+        ACLFilledChecklist bodyContinuationCheck(Config.accessList.forceRequestBodyContinuation, request, nullptr);
         bodyContinuationCheck.al = http->al;
         bodyContinuationCheck.syncAle(request, http->log_uri);
         if (bodyContinuationCheck.fastCheck().allowed()) {
@@ -1640,14 +1644,14 @@ void
 Ftp::Server::setDataCommand()
 {
     ClientHttpRequest *const http = pipeline.front()->http;
-    assert(http != NULL);
+    assert(http != nullptr);
     HttpRequest *const request = http->request;
-    assert(request != NULL);
+    assert(request != nullptr);
     HttpHeader &header = request->header;
-    header.delById(Http::HdrType::FTP_COMMAND);
-    header.putStr(Http::HdrType::FTP_COMMAND, "PASV");
-    header.delById(Http::HdrType::FTP_ARGUMENTS);
-    header.putStr(Http::HdrType::FTP_ARGUMENTS, "");
+    static const SBuf pasvValue("PASV");
+    header.updateOrAddStr(Http::HdrType::FTP_COMMAND, pasvValue);
+    static const SBuf emptyValue("");
+    header.updateOrAddStr(Http::HdrType::FTP_ARGUMENTS, emptyValue);
     debugs(9, 5, "client data command converted to fake PASV");
 }
 
@@ -1704,7 +1708,7 @@ Ftp::Server::connectedForData(const CommConnectCbParams &params)
         setReply(425, "Cannot open data connection.");
         Http::StreamPointer context = pipeline.front();
         Must(context->http);
-        Must(context->http->storeEntry() != NULL);
+        Must(context->http->storeEntry() != nullptr);
         // TODO: call closeDataConnection() to reset data conn processing?
     } else {
         // Finalize the details and start owning the supplied connection.
@@ -1726,19 +1730,18 @@ Ftp::Server::setReply(const int code, const char *msg)
 {
     Http::StreamPointer context = pipeline.front();
     ClientHttpRequest *const http = context->http;
-    assert(http != NULL);
-    assert(http->storeEntry() == NULL);
+    assert(http != nullptr);
+    assert(http->storeEntry() == nullptr);
 
     HttpReply *const reply = Ftp::HttpReplyWrapper(code, msg, Http::scNoContent, 0);
 
     clientStreamNode *const node = context->getClientReplyContext();
     clientReplyContext *const repContext =
         dynamic_cast<clientReplyContext *>(node->data.getRaw());
-    assert(repContext != NULL);
+    assert(repContext != nullptr);
 
     RequestFlags reqFlags;
-    reqFlags.cachable = false; // force releaseRequest() in storeCreateEntry()
-    reqFlags.noCache = true;
+    reqFlags.disableCacheUse("FTP response wrapper");
     repContext->createStoreEntry(http->request->method, reqFlags);
     http->storeEntry()->replaceHttpReply(reply);
 }
