@@ -8,8 +8,8 @@
 
 /* DEBUG: section 33    Client-side Routines */
 
-#ifndef SQUID_SERVERS_FTP_SERVER_H
-#define SQUID_SERVERS_FTP_SERVER_H
+#ifndef SQUID_SRC_SERVERS_FTPSERVER_H
+#define SQUID_SRC_SERVERS_FTPSERVER_H
 
 #include "base/JobWait.h"
 #include "base/Lock.h"
@@ -208,5 +208,5 @@ private:
 
 } // namespace Ftp
 
-#endif /* SQUID_SERVERS_FTP_SERVER_H */
+#endif /* SQUID_SRC_SERVERS_FTPSERVER_H */
 
