@@ -8,8 +8,8 @@
 
 /* DEBUG: section 49    SNMP Interface */
 
-#ifndef SQUID_SNMPX_REQUEST_H
-#define SQUID_SNMPX_REQUEST_H
+#ifndef SQUID_SRC_SNMP_REQUEST_H
+#define SQUID_SRC_SNMP_REQUEST_H
 
 #include "ip/Address.h"
 #include "ipc/forward.h"
@@ -29,8 +29,8 @@ public:
 
     explicit Request(const Ipc::TypedMsgHdr& msg); ///< from recvmsg()
     /* Ipc::Request API */
-    virtual void pack(Ipc::TypedMsgHdr& msg) const;
-    virtual Pointer clone() const;
+    void pack(Ipc::TypedMsgHdr& msg) const override;
+    Pointer clone() const override;
 
 public:
     Pdu pdu; ///< SNMP protocol data unit
@@ -41,5 +41,5 @@ public:
 
 } // namespace Snmp
 
-#endif /* SQUID_SNMPX_REQUEST_H */
+#endif /* SQUID_SRC_SNMP_REQUEST_H */
 
