@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2022 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2023 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
@@ -8,8 +8,8 @@
 
 /* DEBUG: section 49    SNMP Interface */
 
-#ifndef SQUID_SNMPX_SESSION_H
-#define SQUID_SNMPX_SESSION_H
+#ifndef SQUID_SRC_SNMP_SESSION_H
+#define SQUID_SRC_SNMP_SESSION_H
 
 #include "ipc/forward.h"
 #include "snmp.h"
@@ -36,5 +36,5 @@ private:
 
 } // namespace Snmp
 
-#endif /* SQUID_SNMPX_SESSION_H */
+#endif /* SQUID_SRC_SNMP_SESSION_H */
 
