@@ -6,13 +6,13 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_SSL_HELPER_H
-#define SQUID_SSL_HELPER_H
+#ifndef SQUID_SRC_SSL_HELPER_H
+#define SQUID_SRC_SSL_HELPER_H
 
 #if USE_OPENSSL
 
 #include "base/AsyncJobCalls.h"
-#include "base/LruMap.h"
+#include "base/ClpMap.h"
 #include "helper/forward.h"
 #include "security/forward.h"
 #include "ssl/cert_validate_message.h"
@@ -43,23 +43,24 @@ class CertValidationResponse;
 class CertValidationHelper
 {
 public:
-    typedef UnaryMemFunT<Security::PeerConnector, CertValidationResponse::Pointer> CbDialer;
+    using Answer = CertValidationResponse::Pointer;
+    using Callback = AsyncCallback<Answer>;
 
     typedef void CVHCB(void *, Ssl::CertValidationResponse const &);
     static void Init(); ///< Init helper structure.
     static void Shutdown(); ///< Shutdown helper structure.
     static void Reconfigure(); ///< Reconfigure helper structure
     /// Submit crtd request message to external crtd server.
-    static void Submit(Ssl::CertValidationRequest const & request, AsyncCall::Pointer &);
+    static void Submit(const Ssl::CertValidationRequest &, const Callback &);
 private:
     static helper * ssl_crt_validator; ///< helper for management of ssl_crtd.
 public:
-    typedef LruMap<SBuf, Ssl::CertValidationResponse::Pointer, sizeof(Ssl::CertValidationResponse::Pointer) + sizeof(Ssl::CertValidationResponse)> LruCache;
-    static LruCache *HelperCache; ///< cache for cert validation helper
+    typedef ClpMap<SBuf, CertValidationResponse::Pointer, CertValidationResponse::MemoryUsedByResponse> CacheType;
+    static CacheType *HelperCache; ///< cache for cert validation helper
 };
 
 } //namespace Ssl
 
 #endif /* USE_OPENSSL */
-#endif // SQUID_SSL_HELPER_H
+#endif /* SQUID_SRC_SSL_HELPER_H */
 
