@@ -9,15 +9,23 @@
 /* DEBUG: section 47    Store Directory Routines */
 
 #include "squid.h"
-#include "Debug.h"
+#include "base/IoManip.h"
+#include "cache_cf.h"
+#include "ConfigParser.h"
+#include "debug/Messages.h"
+#include "debug/Stream.h"
 #include "globals.h"
-#include "profiler/Profiler.h"
+#include "sbuf/Stream.h"
 #include "SquidConfig.h"
 #include "Store.h"
 #include "store/Disk.h"
 #include "store/Disks.h"
+#include "store_rebuild.h"
+#include "StoreFileSystem.h"
 #include "swap_log_op.h"
-#include "util.h" // for tvSubDsec() which should be in SquidTime.h
+#include "tools.h"
+
+typedef SwapDir *STDIRSELECT(const StoreEntry *e);
 
 static STDIRSELECT storeDirSelectSwapDirRoundRobin;
 static STDIRSELECT storeDirSelectSwapDirLeastLoad;
@@ -25,7 +33,7 @@ static STDIRSELECT storeDirSelectSwapDirLeastLoad;
  * This function pointer is set according to 'store_dir_select_algorithm'
  * in squid.conf.
  */
-STDIRSELECT *storeDirSelectSwapDir = storeDirSelectSwapDirLeastLoad;
+static STDIRSELECT *storeDirSelectSwapDir = storeDirSelectSwapDirLeastLoad;
 
 /// The entry size to use for Disk::canStore() size limit checks.
 /// This is an optimization to avoid similar calculations in every cache_dir.
@@ -45,12 +53,23 @@ objectSizeForDirSelection(const StoreEntry &entry)
     return minSize;
 }
 
+/// TODO: Remove when cache_dir-iterating functions are converted to Disks methods
+static SwapDir &
+SwapDirByIndex(const int i)
+{
+    assert(i >= 0);
+    assert(i < Config.cacheSwap.n_allocated);
+    const auto sd = INDEXSD(i);
+    assert(sd);
+    return *sd;
+}
+
 /**
  * This new selection scheme simply does round-robin on all SwapDirs.
  * A SwapDir is skipped if it is over the max_size (100%) limit, or
  * overloaded.
  */
-static int
+static SwapDir *
 storeDirSelectSwapDirRoundRobin(const StoreEntry * e)
 {
     const int64_t objsize = objectSizeForDirSelection(*e);
@@ -63,20 +82,20 @@ storeDirSelectSwapDirRoundRobin(const StoreEntry * e)
 
     for (int i = 0; i < Config.cacheSwap.n_configured; ++i) {
         const int dirn = (firstCandidate + i) % Config.cacheSwap.n_configured;
-        const SwapDir *sd = dynamic_cast<SwapDir*>(INDEXSD(dirn));
+        auto &dir = SwapDirByIndex(dirn);
 
         int load = 0;
-        if (!sd->canStore(*e, objsize, load))
+        if (!dir.canStore(*e, objsize, load))
             continue;
 
         if (load < 0 || load > 1000) {
             continue;
         }
 
-        return dirn;
+        return &dir;
     }
 
-    return -1;
+    return nullptr;
 }
 
 /**
@@ -92,24 +111,23 @@ storeDirSelectSwapDirRoundRobin(const StoreEntry * e)
  * ALL swapdirs, regardless of state. Again, this is a hack while
  * we sort out the real usefulness of this algorithm.
  */
-static int
+static SwapDir *
 storeDirSelectSwapDirLeastLoad(const StoreEntry * e)
 {
     int64_t most_free = 0;
     int64_t best_objsize = -1;
     int least_load = INT_MAX;
     int load;
-    int dirn = -1;
+    SwapDir *selectedDir = nullptr;
     int i;
-    RefCount<SwapDir> SD;
 
     const int64_t objsize = objectSizeForDirSelection(*e);
 
     for (i = 0; i < Config.cacheSwap.n_configured; ++i) {
-        SD = dynamic_cast<SwapDir *>(INDEXSD(i));
-        SD->flags.selected = false;
+        auto &sd = SwapDirByIndex(i);
+        sd.flags.selected = false;
 
-        if (!SD->canStore(*e, objsize, load))
+        if (!sd.canStore(*e, objsize, load))
             continue;
 
         if (load < 0 || load > 1000)
@@ -118,7 +136,7 @@ storeDirSelectSwapDirLeastLoad(const StoreEntry * e)
         if (load > least_load)
             continue;
 
-        const int64_t cur_free = SD->maxSize() - SD->currentSize();
+        const int64_t cur_free = sd.maxSize() - sd.currentSize();
 
         /* If the load is equal, then look in more details */
         if (load == least_load) {
@@ -126,8 +144,8 @@ storeDirSelectSwapDirLeastLoad(const StoreEntry * e)
             if (best_objsize != -1) {
                 // cache_dir with the smallest max-size gets the known-size object
                 // cache_dir with the largest max-size gets the unknown-size object
-                if ((objsize != -1 && SD->maxObjectSize() > best_objsize) ||
-                        (objsize == -1 && SD->maxObjectSize() < best_objsize))
+                if ((objsize != -1 && sd.maxObjectSize() > best_objsize) ||
+                        (objsize == -1 && sd.maxObjectSize() < best_objsize))
                     continue;
             }
 
@@ -137,15 +155,15 @@ storeDirSelectSwapDirLeastLoad(const StoreEntry * e)
         }
 
         least_load = load;
-        best_objsize = SD->maxObjectSize();
+        best_objsize = sd.maxObjectSize();
         most_free = cur_free;
-        dirn = i;
+        selectedDir = &sd;
     }
 
-    if (dirn >= 0)
-        dynamic_cast<SwapDir *>(INDEXSD(dirn))->flags.selected = true;
+    if (selectedDir)
+        selectedDir->flags.selected = true;
 
-    return dirn;
+    return selectedDir;
 }
 
 Store::Disks::Disks():
@@ -158,15 +176,13 @@ Store::Disks::Disks():
 SwapDir *
 Store::Disks::store(int const x) const
 {
-    return INDEXSD(x);
+    return &SwapDirByIndex(x);
 }
 
 SwapDir &
 Store::Disks::Dir(const int i)
 {
-    SwapDir *sd = INDEXSD(i);
-    assert(sd);
-    return *sd;
+    return SwapDirByIndex(i);
 }
 
 int
@@ -224,11 +240,11 @@ Store::Disks::get(const cache_key *key)
         static int idx = 0;
         for (int n = 0; n < cacheDirs; ++n) {
             idx = (idx + 1) % cacheDirs;
-            SwapDir *sd = dynamic_cast<SwapDir*>(INDEXSD(idx));
-            if (!sd->active())
+            auto &sd = Dir(idx);
+            if (!sd.active())
                 continue;
 
-            if (StoreEntry *e = sd->get(key)) {
+            if (auto e = sd.get(key)) {
                 debugs(20, 7, "cache_dir " << idx << " has: " << *e);
                 return e;
             }
@@ -253,21 +269,26 @@ Store::Disks::init()
     /* this is very bogus, its specific to the any Store maintaining an
      * in-core index, not global */
     size_t buckets = (Store::Root().maxSize() + Config.memMaxSize) / Config.Store.avgObjectSize;
-    debugs(20, DBG_IMPORTANT, "Swap maxSize " << (Store::Root().maxSize() >> 10) <<
+    debugs(20, Important(31), "Swap maxSize " << (Store::Root().maxSize() >> 10) <<
            " + " << ( Config.memMaxSize >> 10) << " KB, estimated " << buckets << " objects");
     buckets /= Config.Store.objectsPerBucket;
-    debugs(20, DBG_IMPORTANT, "Target number of buckets: " << buckets);
+    debugs(20, Important(32), "Target number of buckets: " << buckets);
     /* ideally the full scan period should be configurable, for the
      * moment it remains at approximately 24 hours.  */
     store_hash_buckets = storeKeyHashBuckets(buckets);
-    debugs(20, DBG_IMPORTANT, "Using " << store_hash_buckets << " Store buckets");
-    debugs(20, DBG_IMPORTANT, "Max Mem  size: " << ( Config.memMaxSize >> 10) << " KB" <<
+    debugs(20, Important(33), "Using " << store_hash_buckets << " Store buckets");
+    debugs(20, Important(34), "Max Mem  size: " << ( Config.memMaxSize >> 10) << " KB" <<
            (Config.memShared ? " [shared]" : ""));
-    debugs(20, DBG_IMPORTANT, "Max Swap size: " << (Store::Root().maxSize() >> 10) << " KB");
+    debugs(20, Important(35), "Max Swap size: " << (Store::Root().maxSize() >> 10) << " KB");
 
     store_table = hash_create(storeKeyHashCmp,
                               store_hash_buckets, storeKeyHashHash);
 
+    // Increment _before_ any possible storeRebuildComplete() calls so that
+    // storeRebuildComplete() can reliably detect when all disks are done. The
+    // level is decremented in each corresponding storeRebuildComplete() call.
+    StoreController::store_dirs_rebuilding += Config.cacheSwap.n_configured;
+
     for (int i = 0; i < Config.cacheSwap.n_configured; ++i) {
         /* this starts a search of the store dirs, loading their
          * index. under the new Store api this should be
@@ -285,6 +306,8 @@ Store::Disks::init()
          */
         if (Dir(i).active())
             store(i)->init();
+        else
+            storeRebuildComplete(nullptr);
     }
 
     if (strcasecmp(Config.store_dir_select_algorithm, "round-robin") == 0) {
@@ -292,7 +315,7 @@ Store::Disks::init()
         debugs(47, DBG_IMPORTANT, "Using Round Robin store dir selection");
     } else {
         storeDirSelectSwapDir = storeDirSelectSwapDirLeastLoad;
-        debugs(47, DBG_IMPORTANT, "Using Least Load store dir selection");
+        debugs(47, Important(36), "Using Least Load store dir selection");
     }
 }
 
@@ -355,14 +378,25 @@ Store::Disks::maxObjectSize() const
 }
 
 void
-Store::Disks::updateLimits()
+Store::Disks::configure()
 {
+    if (!Config.cacheSwap.swapDirs)
+        Controller::store_dirs_rebuilding = 0; // nothing to index
+
     largestMinimumObjectSize = -1;
     largestMaximumObjectSize = -1;
     secondLargestMaximumObjectSize = -1;
 
+    Config.cacheSwap.n_strands = 0;
+
     for (int i = 0; i < Config.cacheSwap.n_configured; ++i) {
-        const auto &disk = Dir(i);
+        auto &disk = Dir(i);
+        if (disk.needsDiskStrand()) {
+            assert(InDaemonMode());
+            // XXX: Do not pretend to support disk.disker changes during reconfiguration
+            disk.disker = Config.workers + (++Config.cacheSwap.n_strands);
+        }
+
         if (!disk.active())
             continue;
 
@@ -378,6 +412,70 @@ Store::Disks::updateLimits()
     }
 }
 
+void
+Store::Disks::Parse(DiskConfig &swap)
+{
+    const auto typeStr = ConfigParser::NextToken();
+    if (!typeStr)
+        throw TextException("missing cache_dir parameter: storage type", Here());
+
+    const auto pathStr = ConfigParser::NextToken();
+    if (!pathStr)
+        throw TextException("missing cache_dir parameter: directory name", Here());
+
+    const auto fs = StoreFileSystem::FindByType(typeStr);
+    if (!fs) {
+        debugs(3, DBG_PARSE_NOTE(DBG_IMPORTANT), "ERROR: This proxy does not support the '" << typeStr << "' cache type. Ignoring.");
+        return;
+    }
+
+    const auto fsType = fs->type();
+
+    // check for the existing cache_dir
+    // XXX: This code mistreats duplicated cache_dir entries (that should be fatal).
+    for (int i = 0; i < swap.n_configured; ++i) {
+        auto &disk = Dir(i);
+        if ((strcasecmp(pathStr, disk.path)) == 0) {
+            /* this is specific to on-fs Stores. The right
+             * way to handle this is probably to have a mapping
+             * from paths to stores, and have on-fs stores
+             * register with that, and lookip in that in their
+             * own setup logic. RBC 20041225. TODO.
+             */
+
+            if (strcmp(disk.type(), fsType) == 0)
+                disk.reconfigure();
+            else
+                debugs(3, DBG_CRITICAL, "ERROR: Can't change type of existing cache_dir " <<
+                       disk.type() << " " << disk.path << " to " << fsType << ". Restart required");
+
+            return;
+        }
+    }
+
+    const int cacheDirCountLimit = 64; // StoreEntry::swap_dirn is a signed 7-bit integer
+    if (swap.n_configured >= cacheDirCountLimit)
+        throw TextException(ToSBuf("Squid cannot handle more than ", cacheDirCountLimit, " cache_dir directives"), Here());
+
+    // create a new cache_dir
+    allocate_new_swapdir(swap);
+    swap.swapDirs[swap.n_configured] = fs->createSwapDir();
+    auto &disk = Dir(swap.n_configured);
+    disk.parse(swap.n_configured, pathStr);
+    ++swap.n_configured;
+}
+
+void
+Store::Disks::Dump(const DiskConfig &swap, StoreEntry &entry, const char *name)
+{
+    for (int i = 0; i < swap.n_configured; ++i) {
+        const auto &disk = Dir(i);
+        storeAppendPrintf(&entry, "%s %s %s", name, disk.type(), disk.path);
+        disk.dump(entry);
+        storeAppendPrintf(&entry, "\n");
+    }
+}
+
 int64_t
 Store::Disks::accumulateMore(const StoreEntry &entry) const
 {
@@ -470,7 +568,7 @@ Store::Disks::maintain()
     /* walk each fs */
 
     for (i = 0; i < Config.cacheSwap.n_configured; ++i) {
-        /* XXX FixMe: This should be done "in parallell" on the different
+        /* XXX FixMe: This should be done "in parallel" on the different
          * cache_dirs, not one at a time.
          */
         /* call the maintain function .. */
@@ -512,8 +610,11 @@ Store::Disks::evictIfFound(const cache_key *key)
 }
 
 bool
-Store::Disks::anchorToCache(StoreEntry &entry, bool &inSync)
+Store::Disks::anchorToCache(StoreEntry &entry)
 {
+    if (entry.hasDisk())
+        return true; // already anchored
+
     if (const int cacheDirs = Config.cacheSwap.n_configured) {
         // ask each cache_dir until the entry is found; use static starting
         // point to avoid asking the same subset of disks more often
@@ -525,7 +626,7 @@ Store::Disks::anchorToCache(StoreEntry &entry, bool &inSync)
             if (!sd.active())
                 continue;
 
-            if (sd.anchorToCache(entry, inSync)) {
+            if (sd.anchorToCache(entry)) {
                 debugs(20, 3, "cache_dir " << idx << " anchors " << entry);
                 return true;
             }
@@ -541,7 +642,7 @@ bool
 Store::Disks::updateAnchored(StoreEntry &entry)
 {
     return entry.hasDisk() &&
-           Dir(entry.swap_dirn).updateAnchored(entry);
+           entry.disk().updateAnchored(entry);
 }
 
 bool
@@ -557,6 +658,12 @@ Store::Disks::SmpAware()
     return false;
 }
 
+SwapDir *
+Store::Disks::SelectSwapDir(const StoreEntry *e)
+{
+    return storeDirSelectSwapDir(e);
+}
+
 bool
 Store::Disks::hasReadableEntry(const StoreEntry &e) const
 {
@@ -570,14 +677,14 @@ void
 storeDirOpenSwapLogs()
 {
     for (int dirn = 0; dirn < Config.cacheSwap.n_configured; ++dirn)
-        INDEXSD(dirn)->openLog();
+        SwapDirByIndex(dirn).openLog();
 }
 
 void
 storeDirCloseSwapLogs()
 {
     for (int dirn = 0; dirn < Config.cacheSwap.n_configured; ++dirn)
-        INDEXSD(dirn)->closeLog();
+        SwapDirByIndex(dirn).closeLog();
 }
 
 /**
@@ -592,12 +699,11 @@ storeDirCloseSwapLogs()
 int
 storeDirWriteCleanLogs(int reopen)
 {
-    const StoreEntry *e = NULL;
+    const StoreEntry *e = nullptr;
     int n = 0;
 
     struct timeval start;
     double dt;
-    RefCount<SwapDir> sd;
     int dirn;
     int notdone = 1;
 
@@ -605,20 +711,20 @@ storeDirWriteCleanLogs(int reopen)
     // initialization phases, before store log is initialized and ready. Also,
     // some stores do not support log cleanup during Store rebuilding.
     if (StoreController::store_dirs_rebuilding) {
-        debugs(20, DBG_IMPORTANT, "Not currently OK to rewrite swap log.");
-        debugs(20, DBG_IMPORTANT, "storeDirWriteCleanLogs: Operation aborted.");
+        debugs(20, Important(37), "Not currently OK to rewrite swap log.");
+        debugs(20, Important(38), "storeDirWriteCleanLogs: Operation aborted.");
         return 0;
     }
 
-    debugs(20, DBG_IMPORTANT, "storeDirWriteCleanLogs: Starting...");
+    debugs(20, Important(39), "storeDirWriteCleanLogs: Starting...");
     getCurrentTime();
     start = current_time;
 
     for (dirn = 0; dirn < Config.cacheSwap.n_configured; ++dirn) {
-        sd = dynamic_cast<SwapDir *>(INDEXSD(dirn));
+        auto &sd = SwapDirByIndex(dirn);
 
-        if (sd->writeCleanStart() < 0) {
-            debugs(20, DBG_IMPORTANT, "log.clean.start() failed for dir #" << sd->index);
+        if (sd.writeCleanStart() < 0) {
+            debugs(20, DBG_IMPORTANT, "ERROR: log.clean.start() failed for dir #" << sd.index);
             continue;
         }
     }
@@ -632,22 +738,22 @@ storeDirWriteCleanLogs(int reopen)
         notdone = 0;
 
         for (dirn = 0; dirn < Config.cacheSwap.n_configured; ++dirn) {
-            sd = dynamic_cast<SwapDir *>(INDEXSD(dirn));
+            auto &sd = SwapDirByIndex(dirn);
 
-            if (NULL == sd->cleanLog)
+            if (!sd.cleanLog)
                 continue;
 
-            e = sd->cleanLog->nextEntry();
+            e = sd.cleanLog->nextEntry();
 
             if (!e)
                 continue;
 
             notdone = 1;
 
-            if (!sd->canLog(*e))
+            if (!sd.canLog(*e))
                 continue;
 
-            sd->cleanLog->write(*e);
+            sd.cleanLog->write(*e);
 
             if ((++n & 0xFFFF) == 0) {
                 getCurrentTime();
@@ -659,7 +765,7 @@ storeDirWriteCleanLogs(int reopen)
 
     /* Flush */
     for (dirn = 0; dirn < Config.cacheSwap.n_configured; ++dirn)
-        dynamic_cast<SwapDir *>(INDEXSD(dirn))->writeCleanDone();
+        SwapDirByIndex(dirn).writeCleanDone();
 
     if (reopen)
         storeDirOpenSwapLogs();
@@ -668,8 +774,8 @@ storeDirWriteCleanLogs(int reopen)
 
     dt = tvSubDsec(start, current_time);
 
-    debugs(20, DBG_IMPORTANT, "  Finished.  Wrote " << n << " entries.");
-    debugs(20, DBG_IMPORTANT, "  Took "<< std::setw(3)<< std::setprecision(2) << dt <<
+    debugs(20, Important(40), "  Finished.  Wrote " << n << " entries.");
+    debugs(20, Important(41), "  Took "<< std::setw(3) << std::setprecision(2) << dt <<
            " seconds ("<< std::setw(6) << ((double) n / (dt > 0.0 ? dt : 1.0)) << " entries/sec).");
 
     return n;
@@ -678,21 +784,21 @@ storeDirWriteCleanLogs(int reopen)
 /* Globals that should be converted to static Store::Disks methods */
 
 void
-allocate_new_swapdir(Store::DiskConfig *swap)
+allocate_new_swapdir(Store::DiskConfig &swap)
 {
-    if (!swap->swapDirs) {
-        swap->n_allocated = 4;
-        swap->swapDirs = new SwapDir::Pointer[swap->n_allocated];
+    if (!swap.swapDirs) {
+        swap.n_allocated = 4;
+        swap.swapDirs = new SwapDir::Pointer[swap.n_allocated];
     }
 
-    if (swap->n_allocated == swap->n_configured) {
-        swap->n_allocated <<= 1;
-        const auto tmp = new SwapDir::Pointer[swap->n_allocated];
-        for (int i = 0; i < swap->n_configured; ++i) {
-            tmp[i] = swap->swapDirs[i];
+    if (swap.n_allocated == swap.n_configured) {
+        swap.n_allocated <<= 1;
+        const auto tmp = new SwapDir::Pointer[swap.n_allocated];
+        for (int i = 0; i < swap.n_configured; ++i) {
+            tmp[i] = swap.swapDirs[i];
         }
-        delete[] swap->swapDirs;
-        swap->swapDirs = tmp;
+        delete[] swap.swapDirs;
+        swap.swapDirs = tmp;
     }
 }
 
@@ -748,8 +854,8 @@ storeDirSwapLog(const StoreEntry * e, int op)
            swap_log_op_str[op] << " " <<
            e->getMD5Text() << " " <<
            e->swap_dirn << " " <<
-           std::hex << std::uppercase << std::setfill('0') << std::setw(8) << e->swap_filen);
+           asHex(e->swap_filen).upperCase().minDigits(8));
 
-    dynamic_cast<SwapDir *>(INDEXSD(e->swap_dirn))->logEntry(*e, op);
+    e->disk().logEntry(*e, op);
 }
 
