@@ -1,13 +1,13 @@
 /*
- * Copyright (C) 1996-2022 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2023 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_STORE_LOCAL_SEARCH_H
-#define SQUID_STORE_LOCAL_SEARCH_H
+#ifndef SQUID_SRC_STORE_LOCALSEARCH_H
+#define SQUID_SRC_STORE_LOCALSEARCH_H
 
 #include "store/forward.h"
 
@@ -15,5 +15,5 @@ namespace Store {
 StoreSearch *NewLocalSearch();
 } // namespace Store
 
-#endif /* SQUID_STORE_LOCAL_SEARCH_H */
+#endif /* SQUID_SRC_STORE_LOCALSEARCH_H */
 
