@@ -8,11 +8,11 @@
 
 /* DEBUG: section 20    Storage Manager Swapin Functions */
 
-#ifndef SQUID_STORE_SWAPIN_H_
-#define SQUID_STORE_SWAPIN_H_
+#ifndef SQUID_SRC_STORE_SWAPIN_H
+#define SQUID_SRC_STORE_SWAPIN_H
 
 class store_client;
 void storeSwapInStart(store_client *);
 
-#endif /* SQUID_STORE_SWAPIN_H_ */
+#endif /* SQUID_SRC_STORE_SWAPIN_H */
 
