@@ -7,12 +7,13 @@
  */
 
 #include "squid.h"
-#include "HttpReply.h"
-#include "HttpRequest.h"
+#include "http.h"
 #include "sbuf/SBuf.h"
 
 #define STUB_API "http.cc"
 #include "tests/STUB.h"
 
+class HttpRequest;
+class HttpReply;
 SBuf httpMakeVaryMark(HttpRequest *, HttpReply const *) STUB_RETVAL(SBuf())
 
