@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_SRC_TEST_HTTP_REQUEST_METHOD_H
-#define SQUID_SRC_TEST_HTTP_REQUEST_METHOD_H
+#ifndef SQUID_SRC_TESTS_TESTHTTPREQUESTMETHOD_H
+#define SQUID_SRC_TESTS_TESTHTTPREQUESTMETHOD_H
 
 #include "compat/cppunit.h"
 
@@ -43,5 +43,5 @@ protected:
     void testStream();
 };
 
-#endif
+#endif /* SQUID_SRC_TESTS_TESTHTTPREQUESTMETHOD_H */
 
