@@ -1,13 +1,13 @@
 /*
- * Copyright (C) 1996-2022 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2023 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_TESTLOOKUPTABLE_H_
-#define SQUID_TESTLOOKUPTABLE_H_
+#ifndef SQUID_SRC_TESTS_TESTLOOKUPTABLE_H
+#define SQUID_SRC_TESTS_TESTLOOKUPTABLE_H
 
 #include "compat/cppunit.h"
 
@@ -20,5 +20,5 @@ public:
     void testLookupTableLookup();
 };
 
-#endif /* SQUID_TESTLOOKUPTABLE_H_ */
+#endif /* SQUID_SRC_TESTS_TESTLOOKUPTABLE_H */
 
