@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_SRC_TEST_REFCOUNT_H
-#define SQUID_SRC_TEST_REFCOUNT_H
+#ifndef SQUID_SRC_TESTS_TESTREFCOUNT_H
+#define SQUID_SRC_TESTS_TESTREFCOUNT_H
 
 #include "compat/cppunit.h"
 
@@ -35,5 +35,5 @@ protected:
     void testDoubleInheritToSingleInherit();
 };
 
-#endif
+#endif /* SQUID_SRC_TESTS_TESTREFCOUNT_H */
 
