@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_SRC_TEST_TESTSBUF_H
-#define SQUID_SRC_TEST_TESTSBUF_H
+#ifndef SQUID_SRC_TESTS_TESTSBUFLIST_H
+#define SQUID_SRC_TESTS_TESTSBUFLIST_H
 
 #include "compat/cppunit.h"
 
@@ -22,5 +22,5 @@ protected:
     void testSBufListJoin();
 };
 
-#endif
+#endif /* SQUID_SRC_TESTS_TESTSBUFLIST_H */
 
