@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_TESTSTORESUPPORT_H
-#define SQUID_TESTSTORESUPPORT_H
+#ifndef SQUID_SRC_TESTS_TESTSTORESUPPORT_H
+#define SQUID_SRC_TESTS_TESTSTORESUPPORT_H
 
 #include "EventLoop.h"
 #include "time/Engine.h"
@@ -24,5 +24,5 @@ public:
     Time::Engine default_time_engine;
 };
 
-#endif /* SQUID_TESTSTORESUPPORT_H */
+#endif /* SQUID_SRC_TESTS_TESTSTORESUPPORT_H */
 
