@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID__SRC_TIME_ENGINE_H
-#define SQUID__SRC_TIME_ENGINE_H
+#ifndef SQUID_SRC_TIME_ENGINE_H
+#define SQUID_SRC_TIME_ENGINE_H
 
 namespace Time {
 
@@ -23,5 +23,5 @@ public:
 
 } // namespace Time
 
-#endif /* SQUID__SRC_TIME_ENGINE_H */
+#endif /* SQUID_SRC_TIME_ENGINE_H */
 
