@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef TUNNEL_H_
-#define TUNNEL_H_
+#ifndef SQUID_SRC_TUNNEL_H
+#define SQUID_SRC_TUNNEL_H
 
 #include "comm/forward.h"
 #include "sbuf/forward.h"
@@ -15,5 +15,5 @@
 class HttpRequest;
 void switchToTunnel(HttpRequest *request, const Comm::ConnectionPointer &clientConn, const Comm::ConnectionPointer &srvConn, const SBuf &preReadServerData);
 
-#endif /* TUNNEL_H_ */
+#endif /* SQUID_SRC_TUNNEL_H */
 
