@@ -8,8 +8,8 @@
 
 /* DEBUG: section 02    Unlink Daemon */
 
-#ifndef SQUID_UNLINKD_H_
-#define SQUID_UNLINKD_H_
+#ifndef SQUID_SRC_UNLINKD_H
+#define SQUID_SRC_UNLINKD_H
 
 #if USE_UNLINKD
 bool unlinkdNeeded(void);
@@ -27,5 +27,5 @@ inline void unlinkdClose(void) { return; }
 inline void unlinkdUnlink(const char * path) { ::unlink(path); }
 #endif /* USE_UNLINKD */
 
-#endif /* SQUID_UNLINKD_H_ */
+#endif /* SQUID_SRC_UNLINKD_H */
 
