@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef SQUID_WORDLIST_H
-#define SQUID_WORDLIST_H
+#ifndef SQUID_SRC_WORDLIST_H
+#define SQUID_SRC_WORDLIST_H
 
 #include "globals.h"
 #include "sbuf/List.h"
@@ -65,5 +65,5 @@ char *wordlistChopHead(wordlist **);
 /// convert a wordlist to a SBufList
 SBufList ToSBufList(wordlist *);
 
-#endif /* SQUID_WORDLIST_H */
+#endif /* SQUID_SRC_WORDLIST_H */
 
