@@ -6,8 +6,8 @@
  * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-#ifndef _SQUID_TOOLS_CLIENT_PING_H
-#define _SQUID_TOOLS_CLIENT_PING_H
+#ifndef SQUID_TOOLS_SQUIDCLIENT_PING_H
+#define SQUID_TOOLS_SQUIDCLIENT_PING_H
 
 /**
  * API for looping the squidclient request message
@@ -50,7 +50,7 @@ inline bool LoopDone(int i)
 /// start timing a new transaction
 void TimerStart();
 
-/// calculate and display the statictics for a complete transaction
+/// calculate and display the statistics for a complete transaction
 /// \param fsize number of bytes transferred during this transaction (for KB/s measure)
 void TimerStop(size_t fsize);
 
@@ -59,5 +59,5 @@ void DisplayStats();
 
 } // namespace Ping
 
-#endif /* _SQUID_TOOLS_CLIENT_PING_H */
+#endif /* SQUID_TOOLS_SQUIDCLIENT_PING_H */
 
